@@ -9,7 +9,7 @@
  * enclosed with sources.
  */
 
-/* $Id: prototypes.h,v 1.4 2002/03/05 19:17:57 kiavik Exp $ */
+/* $Id: prototypes.h 81 2004-08-27 21:45:17Z flovergine $ */
 
 /* 
  * PROTOTYPES
@@ -156,13 +156,17 @@ void hexdump(u_char*buf,int n);
 /*--- version.c */
 void version(void);
 void log_version(void);
-void build_version(char *bp);
+void build_version(char *bp,size_t sizeofbp);
 
 /*--- radwatch.c */
 int check_user_time(const char *id, time_t when);
 
-/*--- snprintf.c */
+/*--- filters.c */
+#if defined(ASCEND_BINARY)
+int filterBinary(VALUE_PAIR *pair,char*valstr);
+#endif
 
+/*--- snprintf.c */
 #if !defined(HAVE_LOCAL_SNPRINTF)
 int snprintf (char *str, size_t count, const char *fmt, ...);
 int vsnprintf (char *str, size_t count, const char *fmt, va_list arg);
