@@ -1,14 +1,14 @@
 #ifndef __RADIUS_H
 #define __RADIUS_H
 /*
- * Copyright (C) 1999-2002, Francesco P. Lovergine. All rights reserved.
+ * Copyright (C) 1999-2004, Francesco P. Lovergine. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms stated in the LICENSE file which should be
  * enclosed with sources.
  */
 
-/* $Id: radius.h,v 1.5 2002/03/05 19:17:57 kiavik Exp $ */
+/* $Id: radius.h 81 2004-08-27 21:45:17Z flovergine $ */
 
 #define AUTH_VECTOR_LEN		16
 #define AUTH_PASS_LEN		16
@@ -40,17 +40,22 @@ typedef struct pw_auth_hdr {
 #define PW_TYPE_IPADDR			2
 #define PW_TYPE_DATE			3
 
+#if defined(ASCEND_BINARY)
+#define PW_TYPE_ABINARY			4
+#endif
 
 #define	PW_AUTHENTICATION_REQUEST	1
 #define	PW_AUTHENTICATION_ACK		2
 #define	PW_AUTHENTICATION_REJECT	3
 #define	PW_ACCOUNTING_REQUEST		4
 #define	PW_ACCOUNTING_RESPONSE		5
+
 #ifdef PASSCHANGE
 #define PW_PASSWORD_REQUEST		7
 #define PW_PASSWORD_ACK			8
 #define PW_PASSWORD_REJECT		9
 #endif /* PASSCHANGE */
+
 #define PW_ACCESS_CHALLENGE		11
 
 #define	PW_USER_NAME			1
@@ -69,9 +74,11 @@ typedef struct pw_auth_hdr {
 #define	PW_LOGIN_HOST			14
 #define	PW_LOGIN_SERVICE		15
 #define	PW_LOGIN_TCP_PORT		16
+
 #ifdef PASSCHANGE
 #define PW_OLD_PASSWORD			17
 #endif
+
 #define PW_PORT_MESSAGE			18
 #define PW_DIALBACK_NO			19
 #define PW_DIALBACK_NAME		20
@@ -199,6 +206,7 @@ typedef struct pw_auth_hdr {
 #define PW_AUTHTYPE_CRYPT		3
 #define PW_AUTHTYPE_REJECT		4
 #define PW_AUTHTYPE_ACTIVCARD		5
+
 #if defined(HAVE_LIBPAM)
 #define PW_AUTHTYPE_PAM                 7
 #endif 
@@ -252,6 +260,7 @@ typedef struct pw_auth_hdr {
 #ifdef VPORTS
 #define RADIUS_VPORTS           "vports"
 #endif
+
 #ifdef ACTIVCARD
 #define ACTIVCARD_CONFIG	"config.aeg"
 #endif
@@ -332,13 +341,6 @@ typedef struct peer {
 } PEER;
 
 
-/*
- * This macro is very error prone, use with care in nested if...
- */
-
-#define __debug	if(debug_flag)log_debug
-
-
 
 
 
