@@ -2,14 +2,14 @@
 #define __YARD_H
 
 /*
- * Copyright (C) 1999-2002, Francesco P. Lovergine. All rights reserved.
+ * Copyright (C) 1999-2004, Francesco P. Lovergine. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms stated in the LICENSE file which should be
  * enclosed with sources.
  */
 
-/* $Id: yard.h,v 1.11 2002/03/05 19:17:57 kiavik Exp $ */
+/* $Id: yard.h 81 2004-08-27 21:45:17Z flovergine $ */
 
 /*
  * The main header file with all needed declarations
@@ -121,6 +121,20 @@ typedef unsigned long   UINT4;
 #include 	"prototypes.h"
 #include	"vports.h"
 
+#if defined(ASCEND_BINARY)
+#include	"filters.h"
+#endif
+
+/*
+ * FIXME: Needs some finest autoconf tests to discover if C compiler can handle properly variadic macros.
+ */
+
+#if defined(__GNUC__)
+#define debug(args...)	do { if (debug_flag) log_debug(args); } while(0)
+#else /* C99 syntax */
+#define debug(...) do { if (debug_flag) log_debug( __VA_ARGS__ ); } while(0)
+#endif
+
 #if !defined(USE_PORTABLE_SNPRINTF)
 
 #ifndef HAVE_SNPRINTF
@@ -141,7 +155,7 @@ typedef unsigned long   UINT4;
 #define HAVE_LOCAL_SNPRINTF
 #endif
 
-#endif
+#endif /* !USE_PORTABLE_SNPRINTF */
 
 /*
  * Defines
@@ -292,14 +306,14 @@ int usepamacct=0;
 int usepamauth=0;
 #endif
 
-#else
+#else /* ! __MAIN__ */
 
 #if defined(PAM)
 extern int usepamacct;
 extern int usepamauth;
 #endif
 
-#endif
+#endif /* __MAIN__ */
 
 #endif /* __YARD_H */
 
