@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * Copyright (C) 1999-2004 Francesco P. Lovergine. 
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: acct.c,v 1.7 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: acct.c 81 2004-08-27 21:45:17Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -17,7 +17,8 @@ static char rcsid[] = "$Id: acct.c,v 1.7 2002/03/05 19:17:57 kiavik Exp $";
 #define SIGN_ZERO	1	/* only returned if accept_zero is set */
 #define SIGN_NOMATCH	2
 
-void rad_acctreq(int fd)
+void
+rad_acctreq(int fd)
 {
 	AUTH_REQ                *authreq;
 	UINT4                   addr;
@@ -107,7 +108,8 @@ void rad_acctreq(int fd)
 	return;
 }
 
-int rad_accounting( AUTH_REQ *authreq, int sign )
+int 
+rad_accounting( AUTH_REQ *authreq, int sign )
 {
 	FILE		*outfd;
 	char		buffer[PATH_MAX];
@@ -197,12 +199,13 @@ int rad_accounting( AUTH_REQ *authreq, int sign )
  *
  *************************************************************************/
 
-void send_acct_reply( AUTH_REQ *authreq,VALUE_PAIR *reply,int activefd)
+void 
+send_acct_reply( AUTH_REQ *authreq,VALUE_PAIR *reply,int activefd)
 {
 	extern int		report[];
 	int			total_length;
 
-	__debug("sending acct-response to %s\n", req2strp(authreq));
+	debug("sending acct-response to %s\n", req2strp(authreq));
 
 	total_length = build_packet(authreq,reply,(char *)NULL,PW_ACCOUNTING_RESPONSE,FW_REPLY,send_buffer,sizeof(send_buffer));
 
@@ -227,7 +230,8 @@ void send_acct_reply( AUTH_REQ *authreq,VALUE_PAIR *reply,int activefd)
  *
  *************************************************************************/
 
-int calc_acctreq( UINT4	client,char *secret,int secretlen,u_char *buffer,int buflen ) 
+int 
+calc_acctreq( UINT4	client,char *secret,int secretlen,u_char *buffer,int buflen ) 
 {
 	extern int	accept_zero;
 	AUTH_HDR *auth;
@@ -235,6 +239,7 @@ int calc_acctreq( UINT4	client,char *secret,int secretlen,u_char *buffer,int buf
 	u_char	savedigest[AUTH_VECTOR_LEN];
 	char	hostnm[256];
 	int	len;
+	int	slen;
 
 	/*
 	 * Validate the requesting IP address -
@@ -261,10 +266,11 @@ int calc_acctreq( UINT4	client,char *secret,int secretlen,u_char *buffer,int buf
 		return(SIGN_ZERO);
 	}
 	len = ntohs(auth->length);
+	slen = strlen(secret);
 	memcpy(savedigest,auth->vector,AUTH_VECTOR_LEN);
 	memset(auth->vector, 0, AUTH_VECTOR_LEN);
-	memcpy(buffer+len,secret,buflen-len);
-	md5_calc(digest, buffer, buflen);
+	memcpy(buffer+len,secret,(buflen>(secretlen+len) ? secretlen : 0 ));
+	md5_calc(digest, buffer, (buflen>(secretlen+len) ? len+secretlen : buflen ));
 	memcpy(auth->vector,savedigest,AUTH_VECTOR_LEN);
 	memset(buffer+len,0,buflen-len);
 	if (memcmp(digest,savedigest,AUTH_VECTOR_LEN) == 0) {
