@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * Copyright (C) 1999-2004 Francesco P. Lovergine. 
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: builddbm.c,v 1.6 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: builddbm.c 80 2004-08-19 16:19:18Z flovergine $";
 
 #include	<config.h>
 
@@ -63,7 +63,8 @@ int		lineuser;	/* line current user started on, for error messages */
  *
  *************************************************************************/
 
-void usage(void)
+void 
+usage(void)
 {
 	fprintf(stderr, "Usage: %s", progname);
 	fprintf(stderr, " [-d <db_dir>]");
@@ -76,7 +77,8 @@ void usage(void)
 
 
 
-int main(int argc,char **argv)
+int 
+main(int argc,char **argv)
 {
 	char	argval;
 	char	content[1024];
@@ -222,7 +224,8 @@ int main(int argc,char **argv)
  *
  *************************************************************************/
 
-int user_read(char*name,char*content)
+int 
+user_read(char*name,char*content)
 {
 	extern int	linenum;
 	extern int	lineuser;
