@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * Copyright (C) 1999-2004 Francesco P. Lovergine. 
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: dict.c,v 1.3 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: dict.c 80 2004-08-19 16:19:18Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -26,7 +26,8 @@ static DICT_VALUE	*dictionary_values;
  *
  *************************************************************************/
 
-int dict_init(void)
+int 
+dict_init(void)
 {
 	FILE	*dictfd;
 	char	dummystr[64];
@@ -94,6 +95,12 @@ int dict_init(void)
 			else if(strcmp(typestr, "date") == 0) {
 				type = PW_TYPE_DATE;
 			}
+#if defined(ASCEND_BINARY)
+                        else if(strcmp(typestr, "abinary") == 0) {
+                                type = PW_TYPE_ABINARY;
+                        }
+#endif
+
 			else {
 				log_err("attribute has unknown type on line %d of dictionary %s\n", line_no, dictfile);
 				return(-1);
@@ -217,7 +224,8 @@ int dict_init(void)
  *
  *************************************************************************/
 
-DICT_ATTR*dict_attrget(int attribute)
+DICT_ATTR*
+dict_attrget(int attribute)
 {
 	DICT_ATTR	*attr;
 
@@ -240,7 +248,8 @@ DICT_ATTR*dict_attrget(int attribute)
  *
  *************************************************************************/
 
-DICT_ATTR*dict_vsattrget(int vendor,int vsa)
+DICT_ATTR*
+dict_vsattrget(int vendor,int vsa)
 {
 	DICT_ATTR	*attr;
 
@@ -265,7 +274,8 @@ DICT_ATTR*dict_vsattrget(int vendor,int vsa)
  *
  *************************************************************************/
 
-DICT_ATTR*dict_attrfind(char*attrname)
+DICT_ATTR*
+dict_attrfind(char*attrname)
 {
 	DICT_ATTR	*attr;
 
@@ -288,7 +298,8 @@ DICT_ATTR*dict_attrfind(char*attrname)
  *
  *************************************************************************/
 
-DICT_VALUE*dict_valfind(char *valname)
+DICT_VALUE*
+dict_valfind(char *valname)
 {
 	DICT_VALUE	*val;
 
@@ -311,7 +322,8 @@ DICT_VALUE*dict_valfind(char *valname)
  *
  *************************************************************************/
 
-DICT_VALUE*dict_valget(UINT4 value,char*attrname)
+DICT_VALUE*
+dict_valget(UINT4 value,char*attrname)
 {
 	DICT_VALUE	*val;
 
@@ -334,7 +346,8 @@ DICT_VALUE*dict_valget(UINT4 value,char*attrname)
  *
  *************************************************************************/
 
-int dict_vendor(char *vendname)
+int 
+dict_vendor(char *vendname)
 {
 	DICT_ATTR	*vend;
 
@@ -356,7 +369,8 @@ int dict_vendor(char *vendname)
  *
  *************************************************************************/
 
-void dict_dump(void)
+void 
+dict_dump(void)
 {
   DICT_ATTR *ap;
   DICT_VALUE *vp;
