@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * Copyright (C) 1999-2004 Francesco P. Lovergine. 
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: extens.c,v 1.9 2004/07/01 13:57:55 flovergine Exp $";
+static char rcsid[] = "$Id: extens.c 83 2004-08-28 13:32:47Z flovergine $";
 
 #include	"yard.h"
 #include	"global.h"
@@ -26,7 +26,8 @@ static int usr_speeds[53]={
 /*
  * check_logins - see if maximum number of logins was not reached
  */
-int check_logins(char *user, const int max_logins)
+int 
+check_logins(char *user, const int max_logins)
 {
     char       	dbfile_name[PATH_MAX];
     GDBM_FILE	dbf;
@@ -67,7 +68,8 @@ int check_logins(char *user, const int max_logins)
 /*
  * check_maxtime - see if maximum DAILY/MONTHLY/YEARLY online time is reached
  */
-int check_maxtime(char *user, const int hours, const int kind)
+int 
+check_maxtime(char *user, const int hours, const int kind)
 {
     char       	dbfile_name[PATH_MAX];
     GDBM_FILE	dbf;
@@ -148,11 +150,9 @@ int check_maxtime(char *user, const int hours, const int kind)
  * initializes the user_stats database (clear the number of concurent logins)
  * to avoid starting a new radiusd server with invalid data
  *
- *   Cristian Gafton - <gafton@sorosis.ro>
- *
- *   Corrected a lot of memory leaks - <francesco@yardradius.org>
  */ 
-int clean_user_stats(void)
+int 
+clean_user_stats(void)
 {
     char            dbfile_name[PATH_MAX];
     GDBM_FILE       dbf;
@@ -243,8 +243,8 @@ int clean_user_stats(void)
 
 */
 
-static 
-int listed_on_file(const char *filename, const char *username)
+static int 
+listed_on_file(const char *filename, const char *username)
 {
     FILE *fp;
     char buffer[1024];
@@ -297,7 +297,8 @@ int listed_on_file(const char *filename, const char *username)
 /*
  * The actual function is quite simple ...
  */
-int deny_user(const char *username)
+int 
+deny_user(const char *username)
 {
     char file_name[PATH_MAX];
     char buffer[1024];
@@ -319,7 +320,8 @@ int deny_user(const char *username)
     return 0;
 }
 
-int allow_user(const char *username)
+int 
+allow_user(const char *username)
 {
     char file_name[PATH_MAX];
     char buffer[1024];
@@ -335,7 +337,8 @@ int allow_user(const char *username)
 /*
  * Builds a radlast structure from an AUTHREQ_HDR packet
  */
-static int build_radlast_from_authreq(radlast *rl, AUTH_REQ *authreq)
+static int 
+build_radlast_from_authreq(radlast *rl, AUTH_REQ *authreq)
 {
     int		status_type = 0;
     time_t	crt_time;
@@ -457,8 +460,8 @@ static int build_radlast_from_authreq(radlast *rl, AUTH_REQ *authreq)
  * Updates the user entry from the user_stats databse (add one more login
  * or clear out an entry...
  */
-static int update_db_record(int action, datum *content, radlast *rl,
-                            int month, int day)
+static int 
+update_db_record(int action, datum *content, radlast *rl,int month, int day)
 {	
     void *data;
     int datasize;
@@ -578,8 +581,8 @@ static int update_db_record(int action, datum *content, radlast *rl,
 /*
  * inserts a new entry for the username in the user_stats database
  */
-static 
-int insert_db_record(int action,datum *content,radlast *rl,int month,int day)
+static int 
+insert_db_record(int action,datum *content,radlast *rl,int month,int day)
 {
     user_entry *tmp;
 
@@ -626,7 +629,8 @@ int insert_db_record(int action,datum *content,radlast *rl,int month,int day)
 extern int sockfd;
 extern int acctfd;
 
-static int update_radlast(radlast *rl)
+static int 
+update_radlast(radlast *rl)
 {
     pid_t 	child_pid;
     
@@ -683,7 +687,8 @@ static int update_radlast(radlast *rl)
  * sync with the reality...
  *			--cristiang
  */
-int update_user_status(AUTH_REQ *authreq)
+int 
+update_user_status(AUTH_REQ *authreq)
 {
     GDBM_FILE 	dbf;
     int 	retval;
@@ -708,7 +713,7 @@ int update_user_status(AUTH_REQ *authreq)
 
     time_info = localtime(&rl.ut_time); /* Use start session time */
 
-    __debug("acct: %s user='%s', port=%d, time=%d, input=%d, output=%d\n",
+    debug("acct: %s user='%s', port=%d, time=%d, input=%d, output=%d\n",
 	  (action==PW_STATUS_START)?"start":"stop",
 	  rl.login, rl.ent.port, rl.length, rl.inb, rl.outb);
 
@@ -775,7 +780,8 @@ int update_user_status(AUTH_REQ *authreq)
 #define	DAY	(3600*24)
 #endif
 
-int shadow_expired(const char *user)
+int 
+shadow_expired(const char *user)
 {
     struct spwd *spw;
     int crt_day = time(NULL)/DAY; /* today date */
@@ -783,11 +789,11 @@ int shadow_expired(const char *user)
 	
     if ((user == NULL) || !strlen(user)) {
 	/* invalid call to this function */
-	__debug("shadow_expired: called with null argument\n");
+	debug("shadow_expired: called with null argument\n");
 	/* but the account is not expired... */
 	return 0;
     }
-    __debug("shadow_expired: checking shadow expiration for user '%s'\n", user);	
+    debug("shadow_expired: checking shadow expiration for user '%s'\n", user);	
     setspent();
     spw = getspnam(user);
     if (spw == NULL) {
@@ -843,8 +849,8 @@ static const char *PAM_password;
  *     Purpose: Dialogue between RADIUS and PAM modules.
  */
 
-static int PAM_conv_acct(int num_msg, const struct pam_message **msg,
-			 struct pam_response **resp, void *appdata_ptr)
+static int 
+PAM_conv_acct(int num_msg, const struct pam_message **msg,struct pam_response **resp, void *appdata_ptr)
 {
     int count = 0, replies = 0;
     struct pam_response *reply = NULL;
@@ -897,7 +903,8 @@ static struct pam_conv conv_acct = {
  *              password table + PAM.
  */
 
-int unix_pam(const char *name, const char *passwd, const char *pamauth)
+int 
+unix_pam(const char *name, const char *passwd, const char *pamauth)
 {
     pam_handle_t *pamh=NULL;
     int retval;
@@ -905,25 +912,25 @@ int unix_pam(const char *name, const char *passwd, const char *pamauth)
     PAM_username = name;
     PAM_password = passwd;
 	     
-    __debug("unix_PAM: using pamauth string <%s> for pam.conf lookup\n", pamauth);    
+    debug("unix_PAM: using pamauth string <%s> for pam.conf lookup\n", pamauth);    
     retval = pam_start(pamauth, name, &conv_acct, &pamh);
     if (retval == PAM_SUCCESS) {
-	__debug("unix_PAM: function pam_start succeeded for <%s>\n", name);
+	debug("unix_PAM: function pam_start succeeded for <%s>\n", name);
 	retval = pam_authenticate(pamh, 0);
     }
     if (retval == PAM_SUCCESS) {
-	__debug("unix_PAM: function pam_authenticate succeeded for <%s>\n", name);
+	debug("unix_PAM: function pam_authenticate succeeded for <%s>\n", name);
 	retval = pam_acct_mgmt(pamh, 0);
     }
 
-    /* do not remove block braces, it could break things due to __debug
+    /* do not remove block braces, it could break things due to debug
      * macro */
     
     if (retval == PAM_SUCCESS) {
-	__debug("unix_PAM: function pam_acct_mgmt succeeded for <%s>\n", name);
+	debug("unix_PAM: function pam_acct_mgmt succeeded for <%s>\n", name);
     }
     else {
-	__debug("unix_PAM: PAM FAILED for <%s> failed\n", name);
+	debug("unix_PAM: PAM FAILED for <%s> failed\n", name);
     }
     if (pam_end(pamh, retval) != PAM_SUCCESS) {
 	pamh = NULL;
@@ -937,8 +944,8 @@ int unix_pam(const char *name, const char *passwd, const char *pamauth)
  *     Purpose: A dummy conversation function between the radiusd and the
  *              session modules.
  */
-static int PAM_conv_session(int num_msg, const struct pam_message **msg,
-			    struct pam_response **resp, void *appdata_ptr)
+static int 
+PAM_conv_session(int num_msg, const struct pam_message **msg,struct pam_response **resp, void *appdata_ptr)
 {
     /* this one should never be called; use appdata_ptr instead */
     return PAM_CONV_ERR;
@@ -964,7 +971,8 @@ static pam_handle_t *PAM_handle = NULL;
  *              library about the new sessions being open or closed by
  *		the NASes.
  */
-void pam_session(AUTH_REQ *authreq)
+void 
+pam_session(AUTH_REQ *authreq)
 {
     char		*username = NULL;
     VALUE_PAIR		*pair;
@@ -1003,7 +1011,7 @@ void pam_session(AUTH_REQ *authreq)
      */
     if (PAM_handle == (pam_handle_t *)NULL) {
 	/* we need to open a new session */
-	__debug("about to init PAM session call for %s\n", username);    
+	debug("about to init PAM session call for %s\n", username);    
 	retval = pam_start(RADIUS_PAM_SERVICE, username, &conv_session, &pamh);
 	if (retval != PAM_SUCCESS) {
 
@@ -1051,7 +1059,7 @@ void pam_session(AUTH_REQ *authreq)
     /* all good, now do we start or close a session ? */
     if (type == PW_STATUS_START) {
 	/* start session */
-	__debug("opening session for user %s\n", username);	
+	debug("opening session for user %s\n", username);	
 	retval = pam_open_session(pamh, 0);
 	if (retval != PAM_SUCCESS) {
 #if !defined(OLD_PAM) /* The new pam libraries have 2 params for pam_strerr - misa*/
@@ -1066,7 +1074,7 @@ void pam_session(AUTH_REQ *authreq)
     }
     if (type == PW_STATUS_STOP) {	
 	/* close session */
-	__debug("closing session for user %s\n", username);
+	debug("closing session for user %s\n", username);
 	retval = pam_close_session(pamh, 0);
 	if (retval != PAM_SUCCESS) {
 #if !defined(OLD_PAM) /* The new pam libraries have 2 params for pam_strerr - misa*/
@@ -1102,7 +1110,8 @@ void pam_session(AUTH_REQ *authreq)
 static acct_packet *root_acct_packet = NULL;
 static int acct_queue_entries = 0;
 
-static acct_packet *in_acct_queue(acct_packet *packet, int type)
+static acct_packet *
+in_acct_queue(acct_packet *packet, int type)
 {
     acct_packet *this;
     this = root_acct_packet;
@@ -1123,7 +1132,8 @@ static acct_packet *in_acct_queue(acct_packet *packet, int type)
 /*
  * Adds a pack to the queue
  */
-static int add_acct_queue(acct_packet *packet)
+static int 
+add_acct_queue(acct_packet *packet)
 {
     acct_packet *this, *temp;
 
@@ -1167,7 +1177,8 @@ static int add_acct_queue(acct_packet *packet)
 /*
  * Removes a packet from the queue
  */
-static int remove_acct_queue(acct_packet *packet)
+static int 
+remove_acct_queue(acct_packet *packet)
 {
     acct_packet	*temp, *temp1;
         
@@ -1194,7 +1205,8 @@ static int remove_acct_queue(acct_packet *packet)
  * Delete the oldest pair of (start,stop) packets from the queue
  * to make room for more
  */
-static int cleanup_acct_queue(void)
+static int 
+cleanup_acct_queue(void)
 {
     acct_packet *temp;
 
@@ -1215,7 +1227,8 @@ static int cleanup_acct_queue(void)
  * - a start packet which is not out of order (we haven't seen
  *	the corresponsing packet for it yet
  */
-int validate_acct_packet(AUTH_REQ *authreq)
+int 
+validate_acct_packet(AUTH_REQ *authreq)
 {
     acct_packet packet;
     VALUE_PAIR	*pair;
@@ -1280,7 +1293,8 @@ int validate_acct_packet(AUTH_REQ *authreq)
 static unsigned char itoa64[] =		/* 0 ... 63 => ascii - 64 */
 	"./0123456789ABCDEFGHIJKLMNOPQRSTUVWXYZabcdefghijklmnopqrstuvwxyz";
 
-static void to64(char *s, unsigned long v, int n)
+static void 
+to64(char *s, unsigned long v, int n)
 {
     while (--n >= 0) {
 	*s++ = itoa64[v&0x3f];
@@ -1295,7 +1309,8 @@ static void to64(char *s, unsigned long v, int n)
  */
 
 
-char * crypt_md5(const char *pw, const char *salt)
+char * 
+crypt_md5(const char *pw, const char *salt)
 {
     const char *magic = "$1$";
     /* This string is magic for this algorithm.  Having
@@ -1409,7 +1424,8 @@ char * crypt_md5(const char *pw, const char *salt)
 #define MAX_TIMES 	10	/* max number of time specifications
 				 * in one shot using commas */
 #define SEPARATOR	';'				
-int allowed_time(const char *time_str)
+int 
+allowed_time(const char *time_str)
 {
     struct time_frame	times[MAX_TIMES];
     /* Structures for storing the priorities in the time intervals */
@@ -1430,12 +1446,12 @@ auxdebug = fopen("nighthawk","a");
 
     if (time_str == NULL) {
 	/* cry loud */
-	__debug("allowed_times: passed a null pointer !!!\n");
+	debug("allowed_times: passed a null pointer !!!\n");
 	/* After all, it is okay... */
 	return 0;
     }
     
-    __debug("allowed_time: checking time against %s\n", time_str);
+    debug("allowed_time: checking time against %s\n", time_str);
 #ifdef EXT_DEBUG
 Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 #endif
@@ -1509,7 +1525,7 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 	 * The default is 'Al' if no days were seen.
 	 */
 	if (i == 0) {
-	    __debug("allowed_time: time specification incompete - assuming Al; i=%d\n",i);
+	    debug("allowed_time: time specification incompete - assuming Al; i=%d\n",i);
 	    times[j].t_days = Mo_DAY|Tu_DAY|We_DAY|Th_DAY|Fr_DAY|Sa_DAY|Su_DAY;
 	    beg_day = 0; /* Not a valid day to begin an interval */
 	}
@@ -1521,7 +1537,7 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 	if (cp[i]=='-') {
 		if (beg_day==0) /* Error, cunt have an interval */
 		{
-			__debug("Error in the token %d: cannot have such a day interval; skipped\n",j+1);
+			debug("Error in the token %d: cannot have such a day interval; skipped\n",j+1);
 			error_tokens++;
 			for (;cp[i] && cp[i]!=SEPARATOR;i++);
 			cp += cp[i] ? i+1 : i; /* We jump the bogus token */
@@ -1578,7 +1594,7 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 		*  Nothing means error
 		*/
 		if (end_day==0) {
-			__debug("Error in the token %d: not a valid day\n",j);
+			debug("Error in the token %d: not a valid day\n",j);
 			times[j].t_days = Mo_DAY|Tu_DAY|We_DAY|Th_DAY|Fr_DAY|Sa_DAY|Su_DAY;
 			end_day = 0; /* Not a valid day to end an interval */
 		}
@@ -1611,7 +1627,7 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 	if (cp[i] && isdigit(cp[i]))
 	{
 		/* Ooops, problem, too many digits */
-		__debug("Error in the token %d: too many digits for the begin time; skipped\n",j+1);
+		debug("Error in the token %d: too many digits for the begin time; skipped\n",j+1);
 		/* 
 		 * I try to give up, jumping to the next
 		 * token separator
@@ -1624,7 +1640,7 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 	
 	if (cp[i] != '-' || dtime > 2400 || dtime % 100 > 59)
 	{
-	    __debug("Error in the token %d: begin time invalid; skipped\n",j+1);
+	    debug("Error in the token %d: begin time invalid; skipped\n",j+1);
 	    error_tokens++;
 	    /* See the coments above */
 	    for (;cp[i] && cp[i]!=SEPARATOR;i++);
@@ -1642,7 +1658,7 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 		 * But this time we go over this error, since
 		 * we have found a valid time stamp
 		 */
-		__debug("Error in the token %d: too many digits for the end time\n",j+1);
+		debug("Error in the token %d: too many digits for the end time\n",j+1);
 		error_tokens = -error_tokens - 1;
 	}
 	if (dtime > 2400 || dtime % 100 > 59)
@@ -1650,7 +1666,7 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 	    /* 
 	     * Yet another error in the string
 	    */
-	    __debug("Error in the token %d: end time invalid; skipped\n",j+1);
+	    debug("Error in the token %d: end time invalid; skipped\n",j+1);
 	    error_tokens = error_tokens>=0 ? error_tokens+1 : -error_tokens;
 	    for (; cp[i] && cp[i]!=SEPARATOR; i++);
 	    cp += cp[i] ? i+1 : i; /* We jump the bogus token */
@@ -1708,16 +1724,16 @@ Debug(auxdebug,"allowed_time: checking time against %s\n", time_str);
 	session_timeout = (s_time < curtime && e_time-curtime>0) ? e_time-curtime : 0; 
     }
     if (error_tokens)
-    	__debug(" %d error(s) found in the time string\n",error_tokens);
+    	debug(" %d error(s) found in the time string\n",error_tokens);
     if (session_timeout <= 0) {
-    	__debug("allowed_time: access denied\n");
+    	debug("allowed_time: access denied\n");
 #ifdef EXT_DEBUG
 Debug(auxdebug,"allowed_time: access denied\n");
 fclose(auxdebug);
 #endif
     	return -1;
     }
-    __debug("allowed_time: access allowed for %d seconds\n",session_timeout);
+    debug("allowed_time: access allowed for %d seconds\n",session_timeout);
 #ifdef EXT_DEBUg
 Debug(auxdebug,"allowed_time: access allowed for %d seconds\n",session_timeout);
 fclose(auxdebug);
@@ -1729,7 +1745,8 @@ fclose(auxdebug);
 /*
  * Implement the traffic quota for an user
  */
-int check_maxtraffic(char *user, const int size,const int kind)
+int 
+check_maxtraffic(char *user, const int size,const int kind)
 {	
     char 	dbfile_name[PATH_MAX];
     GDBM_FILE 	dbf;
