@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: log.c,v 1.4 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: log.c 75 2004-08-02 18:40:07Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -20,7 +20,8 @@ static char rcsid[] = "$Id: log.c,v 1.4 2002/03/05 19:17:57 kiavik Exp $";
  *
  *************************************************************************/
 
-void log_info(char * fmt, ...)
+void 
+log_info(char * fmt, ...)
 {
 	va_list	args;
 
@@ -37,7 +38,8 @@ void log_info(char * fmt, ...)
  *
  *************************************************************************/
 
-void log_err(char * fmt, ...)
+void 
+log_err(char * fmt, ...)
 {
 	va_list	args;
 
@@ -54,7 +56,8 @@ void log_err(char * fmt, ...)
  *
  *************************************************************************/
 
-void log_debug(char * fmt, ...)
+void 
+log_debug(char * fmt, ...)
 {
 	va_list	args;
 	
@@ -71,7 +74,8 @@ void log_debug(char * fmt, ...)
  *
  *************************************************************************/
 
-void log_msg(int priority,char *fmt, va_list args)
+void 
+log_msg(int priority,char *fmt, va_list args)
 {
 	FILE	*msgfd;
 	time_t	timeval;
