@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: menu.c,v 1.5 2004/07/01 13:57:55 flovergine Exp $";
+static char rcsid[] = "$Id: menu.c 75 2004-08-02 18:40:07Z flovergine $";
 
 #include	<sys/types.h>
 #include	<sys/socket.h>
@@ -29,21 +29,21 @@ static char rcsid[] = "$Id: menu.c,v 1.5 2004/07/01 13:57:55 flovergine Exp $";
 #include	"yard.h"
 #include	"global.h"
 
-void process_menu(AUTH_REQ*authreq,int activefd,char*pw_digest)
+void 
+process_menu(AUTH_REQ*authreq,int activefd,char*pw_digest)
 {
 	VALUE_PAIR	*attr;
 	VALUE_PAIR	*term_attr;
 	VALUE_PAIR	*newattr;
-	char		menu_name[256];
+	char		menu_name[128];
 	char		menu_input[32];
 	int		i;
-	char		state_value[256];
+	char		state_value[128];
 
 	if((attr = get_attribute(authreq->request, PW_STATE)) !=
 		(VALUE_PAIR *)NULL && strncmp(attr->strvalue, "MENU=", 5) == 0){
 
-		strncpy(menu_name, &attr->strvalue[5], sizeof(menu_name)-1);
-		menu_name[sizeof(menu_name)-1]='\0';
+		strcpy(menu_name, &attr->strvalue[5]);
 
 		/* The menu input is in the Password Field */
 		attr = get_attribute(authreq->request, PW_PASSWORD);
@@ -68,7 +68,7 @@ void process_menu(AUTH_REQ*authreq,int activefd,char*pw_digest)
 							(VALUE_PAIR *)NULL) {
 
 		/* Change this to a menu state */
-		snprintf(state_value,sizeof(state_value),"MENU=%s", term_attr->strvalue);
+		sprintf(state_value, "MENU=%s", term_attr->strvalue);
 		term_attr->attribute = PW_STATE;
 		strcpy(term_attr->strvalue, state_value);
 		strcpy(term_attr->name, "Challenge-State");
@@ -103,7 +103,8 @@ void process_menu(AUTH_REQ*authreq,int activefd,char*pw_digest)
 	return;
 }
 
-char* get_menu(char *menu_name)
+char* 
+get_menu(char *menu_name)
 {
 	FILE	*fd;
 	static	char menu_buffer[4096];
@@ -149,7 +150,8 @@ char* get_menu(char *menu_name)
 	return(menu_buffer);
 }
 
-VALUE_PAIR* menu_pairs(char*menu_name,char*menu_selection)
+VALUE_PAIR* 
+menu_pairs(char*menu_name,char*menu_selection)
 {
 	FILE	*fd;
 	char 	buffer[4096];
@@ -159,7 +161,7 @@ VALUE_PAIR* menu_pairs(char*menu_name,char*menu_selection)
 	int	nread;
 	VALUE_PAIR*reply_first;
 
-	snprintf(buffer, sizeof(buffer), "%s/menus/%s", radius_dir, menu_name);
+	sprintf(buffer, "%s/menus/%s", radius_dir, menu_name);
 	if((fd = fopen(buffer, "r")) == (FILE *)NULL) {
 		return((VALUE_PAIR *)NULL);
 	}
