@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: pass.c,v 1.4 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: pass.c 81 2004-08-27 21:45:17Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -24,7 +24,8 @@ char	pwbuf[MAX_LINE_SIZE];
  *
  *************************************************************************/
 
-int unix_pass(char*name,char*passwd,char*from)
+int 
+unix_pass(char*name,char*passwd,char*from)
 {
 	struct passwd	*pwd;
 	char		*encpw;
@@ -39,7 +40,7 @@ int unix_pass(char*name,char*passwd,char*from)
 	/* Get encrypted password from alternate password file */
 	if (alt_passwd != (char *)NULL) {
 		if((pwd = getownpwnam(name)) == NULL) {
-			__debug("unix_pass: getownpwnam for \"%s\"%s failed\n", 
+			debug("unix_pass: getownpwnam for \"%s\"%s failed\n", 
 				name, from);
 			return(-1);
 		}
@@ -48,7 +49,7 @@ int unix_pass(char*name,char*passwd,char*from)
 	else {
 	/* Get encrypted password from password file */
 		if((pwd = getpwnam(name)) == NULL) {
-			__debug("unix_pass: getpwnam for \"%s\"%s failed\n",
+			debug("unix_pass: getpwnam for \"%s\"%s failed\n",
 				name, from);
 			return(-1);
 		}
@@ -56,7 +57,7 @@ int unix_pass(char*name,char*passwd,char*from)
 #if defined(BSD4_4)
 		/* Return failed if Unix Account is expired (locked out) */
 		if (pwd->pw_expire && (pwd->pw_expire < time((time_t *)NULL))) {
-			__debug("unix_pass: account for \"%s\"%s"
+			debug("unix_pass: account for \"%s\"%s"
 			        " has expired\n",name, from);
 			return(-1);
 		}
@@ -80,7 +81,7 @@ int unix_pass(char*name,char*passwd,char*from)
 
 	/* Check it */
 	if(strcmp(encpw, encrypted_pass)) {
-		__debug("unix_pass: password for \"%s\"%s failed\n", name, from);
+		debug("unix_pass: password for \"%s\"%s failed\n", name, from);
 		return(-1);
 	}
 	return(0);
@@ -95,7 +96,8 @@ int unix_pass(char*name,char*passwd,char*from)
  *
  *************************************************************************/
 
-int unix_group(const char*name,const char*group)
+int 
+unix_group(const char*name,const char*group)
 {
 	struct passwd	*pwd;
 	char		**gr_mem;
@@ -104,19 +106,19 @@ int unix_group(const char*name,const char*group)
 	/* Get encrypted password from alternate password file */
 	if (alt_passwd != (char *)NULL) {
 		if((pwd = getownpwnam(name)) == NULL) {
-			__debug("unix_group: getownpwnam for \"%s\" failed\n", name);
+			debug("unix_group: getownpwnam for \"%s\" failed\n", name);
 			return(-1);
 		}
 	} else {
 	/* Get encrypted password from password file */
 		if((pwd = getpwnam(name)) == NULL) {
-			__debug("unix_group: getpwnam for \"%s\" failed\n", name);
+			debug("unix_group: getpwnam for \"%s\" failed\n", name);
 			return(0);
 		}
 	}
 
 	if((gr_ent = getgrnam(group)) == NULL) {
-		__debug("unix_group: getgrnam(%s) for \"%s\" failed\n", group,name);
+		debug("unix_group: getgrnam(%s) for \"%s\" failed\n", group,name);
 		return(0);
 	}
 
@@ -144,20 +146,21 @@ int unix_group(const char*name,const char*group)
  *
  *************************************************************************/
 
-char *unix_gecos(const char*name)
+char *
+unix_gecos(const char*name)
 {
 	struct passwd	*pwd;
 	
 	/* get encrypted password from alternate password file */
 	if (alt_passwd != (char *)NULL) {
 		if((pwd = getownpwnam(name)) == NULL) {
-			__debug("unix_gecos: getownpwnam for \"%s\" failed\n", name);
+			debug("unix_gecos: getownpwnam for \"%s\" failed\n", name);
 			return "";
 		}
 	} else {
 	/* get encrypted password from password file */
 		if((pwd = getpwnam(name)) == NULL) {
-			__debug("unix_gecos: getpwnam for \"%s\" failed\n", name);
+			debug("unix_gecos: getpwnam for \"%s\" failed\n", name);
 			return "";
 		}
 	}
@@ -174,20 +177,21 @@ char *unix_gecos(const char*name)
  *
  *************************************************************************/
 
-char *unix_shell(const char*name)
+char *
+unix_shell(const char*name)
 {
 	struct passwd	*pwd;
 	
 	/* get encrypted password from alternate password file */
 	if (alt_passwd != (char *)NULL) {
 		if((pwd = getownpwnam(name)) == NULL) {
-			__debug("unix_gecos: getownpwnam for \"%s\" failed\n", name);
+			debug("unix_gecos: getownpwnam for \"%s\" failed\n", name);
 			return "";
 		}
 	} else {
 	/* get encrypted password from password file */
 		if((pwd = getpwnam(name)) == NULL) {
-			__debug("unix_gecos: getpwnam for \"%s\" failed\n", name);
+			debug("unix_gecos: getpwnam for \"%s\" failed\n", name);
 			return "";
 		}
 	}
@@ -195,7 +199,8 @@ char *unix_shell(const char*name)
 	return pwd->pw_shell;
 }
 
-struct passwd *getownpwnam(const char*name)
+struct passwd *
+getownpwnam(const char*name)
 {
 	extern char	*alt_passwd;
 	extern char	pwbuf[];
