@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: proxy.c,v 1.5 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: proxy.c 83 2004-08-28 13:32:47Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -42,7 +42,8 @@ static	PEER	*server_norealm;
  *
  *************************************************************************/
 
-void rad_proxy(int fd)
+void 
+rad_proxy(int fd)
 {
 	extern AUTH_REQ		*first_forwarded;
 	extern int		max_proxy_time;
@@ -115,7 +116,7 @@ void rad_proxy(int fd)
 			break;
 	}
 
-	__debug("proxy server %s/%d.%d replied with code=%d, length=%d\n", ipaddr2strp(host), port, authreq->id, authreq->code, result);
+	debug("proxy server %s/%d.%d replied with code=%d, length=%d\n", ipaddr2strp(host), port, authreq->id, authreq->code, result);
 	if (debug_flag > 2) {
 		hexdump((u_char*)recv_buffer,result);
 	}
@@ -146,7 +147,7 @@ void rad_proxy(int fd)
 	qpop = (AUTH_REQ *)NULL;
 	if (server->flags & PEER_NOPROXY) { /* server can't do proxy */
 		if (qp == (AUTH_REQ *)NULL) {	/* not found in queue */
-			__debug("rad_proxy: response from %s/%d.%d not matched in forwarded queue, dropped\n", ipaddr2strp(host), port, authreq->id);
+			debug("rad_proxy: response from %s/%d.%d not matched in forwarded queue, dropped\n", ipaddr2strp(host), port, authreq->id);
 			reqfree(authreq, "rad_proxy");
 			return;
 		} else {
@@ -169,7 +170,7 @@ void rad_proxy(int fd)
 			/* radiusd has restarted or we've already
 			   forwarded this response, so drop this response
 			 */
-			__debug("rad_proxy: accounting-response from %s/%d.%d not matched in forwarded queue, dropped\n",
+			debug("rad_proxy: accounting-response from %s/%d.%d not matched in forwarded queue, dropped\n",
 				ipaddr2strp(host), port, authreq->id);
 			reqfree(authreq, "rad_proxy");
 			reqfree(qpop, "rad_proxy");
@@ -232,7 +233,8 @@ void rad_proxy(int fd)
  *
  *************************************************************************/
 
-AUTH_REQ *pop_proxy(AUTH_REQ *authreq,AUTH_REQ *qp)
+AUTH_REQ *
+pop_proxy(AUTH_REQ *authreq,AUTH_REQ *qp)
 {
 	VALUE_PAIR	*value_list;
 	VALUE_PAIR	*old_value;
@@ -310,7 +312,8 @@ AUTH_REQ *pop_proxy(AUTH_REQ *authreq,AUTH_REQ *qp)
  *
  *************************************************************************/
 
-void send_proxy2client(int fd,AUTH_REQ*authreq,PEER*server,AUTH_REQ*qp)
+void 
+send_proxy2client(int fd,AUTH_REQ*authreq,PEER*server,AUTH_REQ*qp)
 {
 	AUTH_HDR		*auth;
 	VALUE_PAIR		*curpair;
@@ -358,7 +361,7 @@ void send_proxy2client(int fd,AUTH_REQ*authreq,PEER*server,AUTH_REQ*qp)
 		}
 	}
 
-	__debug("forwarding reply code %d from %s to %s\n",
+	debug("forwarding reply code %d from %s to %s\n",
 		authreq->code, ip_str, req2strp(qp));
 
 	/* Load up the configuration values for the user */
@@ -380,7 +383,8 @@ void send_proxy2client(int fd,AUTH_REQ*authreq,PEER*server,AUTH_REQ*qp)
  *
  *************************************************************************/
 
-int update_proxy(void)
+int 
+update_proxy(void)
 {
 	extern u_short	radacct_port;
 	extern u_short	radius_port;
@@ -487,7 +491,7 @@ int update_proxy(void)
 		while ((arg = strtok((char *)NULL, " \t\n, ")) != (char *)NULL) {
 			if (isdigit(arg[0])) {
 				rport = atoi(arg);
-				if (rport > 0 && rport <= 0xffff) {
+				if (rport > 0) {
 					if (server->radport == 0) {
 						server->radport = rport;
 					} else if (server->acctport == 0) {
@@ -547,7 +551,7 @@ int update_proxy(void)
 	}
 	fclose(fd);
 	last_update_time = statbuf.st_mtime;
-	__debug("found %d proxy realms\n", nproxy);
+	debug("found %d proxy realms\n", nproxy);
 	return(0);
 }
 
@@ -588,7 +592,8 @@ int update_proxy(void)
  *
  *************************************************************************/
 
-int handle_proxy(AUTH_REQ*authreq)
+int 
+handle_proxy(AUTH_REQ*authreq)
 {
 	PEER		*server;
 	VALUE_PAIR	*namepair;
@@ -612,7 +617,7 @@ int handle_proxy(AUTH_REQ*authreq)
 	if (authreq->code != PW_AUTHENTICATION_REQUEST &&
 	    authreq->code != PW_ACCOUNTING_REQUEST) {
 		/* should not happen unless client sent bogus message */
-		__debug("handle_proxy called for packet type %d unexpectedly\n",
+		debug("handle_proxy called for packet type %d unexpectedly\n",
 			authreq->code);
 		authreq->flags |= REQ_ERR|REQ_FREE;
 		return -1;
@@ -716,7 +721,8 @@ int handle_proxy(AUTH_REQ*authreq)
  *
  *************************************************************************/
 
-void push_proxy(AUTH_REQ*authreq)
+void
+push_proxy(AUTH_REQ*authreq)
 {
 	DICT_ATTR       *attr;
 	VALUE_PAIR	*pair;
@@ -730,7 +736,7 @@ void push_proxy(AUTH_REQ*authreq)
 	   a pad byte, and 16 octets of Request Authenticator */
 
  	if((attr = dict_attrget(PW_PROXY)) == (DICT_ATTR *)NULL) {
-		__debug("add Proxy (%d) to dictionary\n", PW_PROXY);
+		debug("add Proxy (%d) to dictionary\n", PW_PROXY);
 		strcpy(pair->name, "Proxy");
 		pair->type = PW_TYPE_STRING;
 	} else {
@@ -771,7 +777,8 @@ void push_proxy(AUTH_REQ*authreq)
  *
  *************************************************************************/
 
-PEER * find_server(char *number,char *realm)
+PEER * 
+find_server(char *number,char *realm)
 {
 	extern PEER	*servers;
 	extern PEER	*server_default;
@@ -815,7 +822,8 @@ PEER * find_server(char *number,char *realm)
  *
  *************************************************************************/
 
-PEER *find_server_byaddr(UINT4 ipaddr,u_short port)
+PEER *
+find_server_byaddr(UINT4 ipaddr,u_short port)
 {
 	PEER	*server;
 	extern PEER	*servers;
@@ -841,7 +849,8 @@ PEER *find_server_byaddr(UINT4 ipaddr,u_short port)
  *
  *************************************************************************/
 
-void send_proxy2server(AUTH_REQ*authreq,PEER*server)
+void 
+send_proxy2server(AUTH_REQ*authreq,PEER*server)
 {
 	extern AUTH_REQ		*first_forwarded;
 	AUTH_HDR		*auth;
@@ -879,7 +888,7 @@ void send_proxy2server(AUTH_REQ*authreq,PEER*server)
 	memcpy(authreq->forw_vector, authreq->vector, AUTH_VECTOR_LEN);
 	strcpy(authreq->forw_secret, server->secret);
 
-	__debug("forwarding request from %s to %s/%d.%d for %s\n",
+	debug("forwarding request from %s to %s/%d.%d for %s\n",
 		ip_str, ipaddr2strp(authreq->forw_addr), authreq->forw_port,
 		authreq->forw_id, authreq->realm);
 
@@ -912,13 +921,14 @@ void send_proxy2server(AUTH_REQ*authreq,PEER*server)
  *
  *************************************************************************/
 
-u_char getnextid(AUTH_REQ *authreq)
+u_char 
+getnextid(AUTH_REQ *authreq)
 {
 	extern AUTH_REQ	*first_forwarded;
 	AUTH_REQ	*qp;
 	AUTH_REQ	*prevqp;
 	static char	inuse[256];
-	u_char	 	newid;
+	u_short	 	newid;
 	static u_char	curid = 0;
 	static int	flushcount = 0;
 	extern int	max_proxy_time;
@@ -932,7 +942,7 @@ u_char getnextid(AUTH_REQ *authreq)
 	while (qp != (AUTH_REQ *)NULL) {
 		if (qp->timestamp + max_proxy_time < now) {
 			if (++flushcount % 100 == 0) {
-				__debug("%d proxy requests expired unanswered\n",flushcount);
+				debug("%d proxy requests expired unanswered\n",flushcount);
 			}
 			if (prevqp == (AUTH_REQ *)NULL) {
 				first_forwarded = qp->next;
@@ -959,7 +969,7 @@ u_char getnextid(AUTH_REQ *authreq)
 			qp = qp->next;
 		}
 	}
-	for (newid = curid; newid < 256; newid++) {
+	for (newid = curid; newid <= 255; newid++) {
 		if (inuse[newid] == 0) {
 			curid = ((newid+1) & 0xff);
 			return newid;
@@ -999,7 +1009,8 @@ u_char getnextid(AUTH_REQ *authreq)
  *
  *************************************************************************/
 
-void proxy_report(void)
+void 
+proxy_report(void)
 {
 	AUTH_REQ	*qp;
 	UINT4		oldest;
