@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * Copyright (C) 1999-2004 Francesco P. Lovergine. 
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: radiusd.c,v 1.9 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: radiusd.c 83 2004-08-28 13:32:47Z flovergine $";
 
 
 #define __MAIN__
@@ -21,7 +21,8 @@ static AUTH_REQ	*first_request;
  *	
  */
 
-int main( int argc,char **argv )
+int 
+main( int argc,char **argv )
 {
   UINT4	then;
   char	argval;
@@ -220,19 +221,19 @@ int main( int argc,char **argv )
   	}
   }
 
-  __debug("initializing dictionary\n");
+  debug("initializing dictionary\n");
   /* Initialize the dictionary */
   if(dict_init() != 0) { rad_exit(-1); }
   dict_dump();
 
-  __debug("initializing configuration values\n");
+  debug("initializing configuration values\n");
   /* Initialize Configuration Values */
   if(config_init() != 0) { rad_exit(-1); }
 
   /*
    *	Disconnect from session
    */
-  __debug("Disconnecting from session\n");
+  debug("Disconnecting from session\n");
   if(debug_flag == 0) {
   	pid = fork();
   	if(pid < 0) {
@@ -248,7 +249,7 @@ int main( int argc,char **argv )
   /*
    *	Disconnect from tty
    */
-  __debug("Disconnecting from tty\n");
+  debug("Disconnecting from tty\n");
   for (t = 32; t >= 3; t--) { close(t); }
 
   /* Show our stuff */
@@ -286,7 +287,7 @@ int main( int argc,char **argv )
          vports_flag = vports_init();
          if (vports_flag == 1 && spawn_flag == 1) {
                  spawn_flag = 0;
-                 __debug("virtual ports disable spawning\n");
+                 debug("virtual ports disable spawning\n");
          }
 #endif /* VPORTS */
 
@@ -374,7 +375,8 @@ int main( int argc,char **argv )
   *
   *************************************************************************/
 
-int open_udpsock(u_short *port,int defport,char *service)
+int 
+open_udpsock(u_short *port,int defport,char *service)
 {
 
   int		fd;
@@ -395,7 +397,7 @@ int open_udpsock(u_short *port,int defport,char *service)
   	}
   	*port = ntohs(lport);
   }
-  __debug("using udp port %d for %s\n", *port,service);
+  debug("using udp port %d for %s\n", *port,service);
 
   fd = socket (AF_INET, SOCK_DGRAM, 0);
   if (fd < 0) {
@@ -430,7 +432,8 @@ int open_udpsock(u_short *port,int defport,char *service)
   *
   *************************************************************************/
 
-void send_packet(int fd, UINT4 ipaddr, u_short port, char * buffer, int length)
+void 
+send_packet(int fd, UINT4 ipaddr, u_short port, char * buffer, int length)
 {
   AUTH_HDR		*auth;
   struct	sockaddr_in	saremote;
@@ -443,7 +446,7 @@ void send_packet(int fd, UINT4 ipaddr, u_short port, char * buffer, int length)
   sin->sin_port = htons(port);
 
   auth = (AUTH_HDR *)buffer;
-  __debug("message sent to %s/%d.%d code=%d, length=%d\n",
+  debug("message sent to %s/%d.%d code=%d, length=%d\n",
   	ipaddr2strp(ipaddr), port, auth->id, auth->code, length);
 
   if (debug_flag > 1) {
@@ -464,7 +467,8 @@ void send_packet(int fd, UINT4 ipaddr, u_short port, char * buffer, int length)
   *
   *************************************************************************/
 
-void rad_request(int fd)
+void 
+rad_request(int fd)
 {
   AUTH_REQ		*authreq;
   UINT4			addr;
@@ -541,7 +545,7 @@ void rad_request(int fd)
 
   if ((pair = get_attribute(authreq->request,PW_STATE)) != (VALUE_PAIR *)NULL) {
   	buf = pair->strvalue;
-  	__debug("rad_request: PW_STATE<%s>\n", buf);
+  	debug("rad_request: PW_STATE<%s>\n", buf);
 #ifdef SECURID
   	/*
   	 * the format for SECURID state string is
@@ -574,7 +578,7 @@ void rad_request(int fd)
   	radrespond(authreq, fd);
   	return;
   }
-  __debug("rad_request: challenge_response from %s for child %d\n",
+  debug("rad_request: challenge_response from %s for child %d\n",
   		req2strp(authreq), child_pid);
 
   curreq = first_request;
@@ -639,7 +643,8 @@ void rad_request(int fd)
   *
   *************************************************************************/
 
-AUTH_REQ *radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int length)
+AUTH_REQ *
+radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int length)
 {
   u_char	*ptr;
   AUTH_HDR	*auth;
@@ -676,7 +681,7 @@ AUTH_REQ *radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int le
   	return((AUTH_REQ *)NULL);
   }
 
-  __debug("message received from %s/%d.%d code=%d, length=%d\n",
+  debug("message received from %s/%d.%d code=%d, length=%d\n",
   	ipaddr2strp(host), udp_port, auth->id, auth->code, totallen);
 
   if (debug_flag > 1) {
@@ -723,7 +728,8 @@ AUTH_REQ *radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int le
   		pair->attribute = attribute;
   		pair->type = PW_TYPE_STRING;
   	} else {
-  		strcpy(pair->name, attr->name);
+  		strncpy(pair->name, attr->name, VALUE_PAIR_NAME_LEN-1);
+		pair->name[VALUE_PAIR_NAME_LEN-1]='\0';
   		pair->attribute = attr->value;
   		pair->type = attr->type;
   	}
@@ -762,7 +768,8 @@ AUTH_REQ *radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int le
   			pair->vendor = vendor;
   			pair->vsattribute = vsa;
   			if((attr = dict_vsattrget(vendor,vsa)) != NULL) {
-  				strcpy(pair->name, attr->name);
+  				strncpy(pair->name, attr->name, VALUE_PAIR_NAME_LEN-1);
+				pair->name[VALUE_PAIR_NAME_LEN-1]='\0';
   				pair->type = attr->type;
   			} else {
 				log_debug("Attribute %d for vendor %d not found\n",vsa,vendor);
@@ -774,6 +781,9 @@ AUTH_REQ *radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int le
 
   	switch(pair->type) {
 
+#if defined(ASCEND_BINARY)
+	case PW_TYPE_ABINARY:
+#endif
   	case PW_TYPE_STRING:
   		memcpy(pair->strvalue, ptr, attrlen);
   		pair->strvalue[attrlen] = '\0';
@@ -804,7 +814,7 @@ AUTH_REQ *radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int le
   		break;
 
   	default:
-  		__debug("    %s (Unknown Type %d)\n",
+  		debug("    %s (Unknown Type %d)\n",
   			attr->name,attr->type);
   		pairfree(pair,"radrecv");
   		break;
@@ -834,7 +844,8 @@ AUTH_REQ *radrecv(UINT4	host,u_short udp_port,char* secret,u_char* buffer,int le
   *
   *************************************************************************/
 
-void radrespond(AUTH_REQ *authreq,int activefd)
+void 
+radrespond(AUTH_REQ *authreq,int activefd)
 {
          if (authreq == (AUTH_REQ *)NULL) {
                  return;
@@ -873,7 +884,8 @@ void radrespond(AUTH_REQ *authreq,int activefd)
 
 int rad_spawned_child_pid;
 
-void rad_spawn_child(AUTH_REQ *authreq,int activefd)
+void 
+rad_spawn_child(AUTH_REQ *authreq,int activefd)
 {
   AUTH_REQ	*curreq;
   AUTH_REQ	*prevreq;
@@ -988,7 +1000,8 @@ void rad_spawn_child(AUTH_REQ *authreq,int activefd)
   }
 }
 
-void clean_child(int pid)
+void 
+clean_child(int pid)
 {
   AUTH_REQ	*curreq;
 
@@ -1005,7 +1018,8 @@ void clean_child(int pid)
   return;
 }
 
-void sig_cleanup(int sig)
+void 
+sig_cleanup(int sig)
 {
   int		status;
          pid_t		pid;
@@ -1036,7 +1050,8 @@ void sig_cleanup(int sig)
   *
   *************************************************************************/
 
-void child_authenticate(AUTH_REQ *authreq,int activefd)
+void 
+child_authenticate(AUTH_REQ *authreq,int activefd)
 {
 #ifdef SMARTCARD
   key_t			msg_key;
@@ -1083,7 +1098,8 @@ void child_authenticate(AUTH_REQ *authreq,int activefd)
   *
   *************************************************************************/
 
-int rad_authenticate(AUTH_REQ *authreq,int activefd)
+int 
+rad_authenticate(AUTH_REQ *authreq,int activefd)
 {
   USER_FILE	user_desc;
   VALUE_PAIR	*attr;
@@ -1224,7 +1240,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
   				retval = pw_expired(check_item->lvalue);
   			if(retval < 0) {
   				result = -2;
-  				snprintf(umsg,(size_t)(AUTH_STRING_LEN+2),"Password Has Expired\r\n");
+  				snprintf(umsg,sizeof(umsg),"Password Has Expired\r\n");
   				user_msg = umsg;
                        		log_err("auth: Password expired for '%s'\n",authreq->name);
   			} else {
@@ -1305,7 +1321,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
                      retval = check_maxtime(auth_name,check_item->lvalue,DAY_LIMIT);
                      if (retval != 0) {
                          result = -2;
-                         sprintf(umsg, "Total on-line daily time expired (%d hours)\r\n",(unsigned int)check_item->lvalue);
+                         snprintf(umsg,sizeof(umsg),"Total on-line daily time expired (%d hours)\r\n",(unsigned int)check_item->lvalue);
                          user_msg = umsg;
                          log_err("Total on-line daily time expired (%d hours) for '%s'\n", (unsigned int)check_item->lvalue, authreq->name);
                      }
@@ -1315,7 +1331,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
                      retval = check_maxtime(auth_name,check_item->lvalue,MONTH_LIMIT);
                      if (retval != 0) {
                          result = -2;
-                         sprintf(umsg, "Total on-line time expired (%d hours)\r\n", (unsigned int)check_item->lvalue);
+                         snprintf(umsg,sizeof(umsg),"Total on-line time expired (%d hours)\r\n", (unsigned int)check_item->lvalue);
                          user_msg = umsg;
                          log_err("Total on-line time expired (%d hours) for '%s'\n", (unsigned int)check_item->lvalue, authreq->name);
                      }
@@ -1325,7 +1341,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
                      retval = check_maxtime(auth_name,check_item->lvalue,YEAR_LIMIT);
                      if (retval != 0) {
                          result = -2;
-                         sprintf(umsg, "Total on-line yearly time expired (%d hours)\r\n", (unsigned int)check_item->lvalue);
+                         snprintf(umsg,sizeof(umsg),"Total on-line yearly time expired (%d hours)\r\n", (unsigned int)check_item->lvalue);
                          user_msg = umsg;
                          log_err("Total on-line yearly time expired (%d hours) for '%s'\n", (unsigned int)check_item->lvalue, authreq->name);
                      }
@@ -1335,7 +1351,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
                      retval = allowed_time(check_item->strvalue);
                      if (retval != 0) {
                          result = -2;
-                         sprintf(umsg, "Not allowed to login at this time\r\n");
+                         snprintf(umsg,sizeof(umsg),"Not allowed to login at this time\r\n");
                          user_msg = umsg;
                          log_err( "Not allowed to login at this time for '%s'\n",authreq->name );
                      }
@@ -1345,7 +1361,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
                      retval = check_maxtraffic(auth_name,check_item->lvalue,DAY_LIMIT);
                      if (retval != 0) {
                          result = -2;
-                         sprintf(umsg, "Maximum allowed daily traffic size reached (%d KB)\r\n",(unsigned int)check_item->lvalue);
+                         snprintf(umsg,sizeof(umsg),"Maximum allowed daily traffic size reached (%d KB)\r\n",(unsigned int)check_item->lvalue);
                          user_msg=umsg;
                          log_err("Maximum allowed daily traffic size reached (%dKB) for '%s'\r\n", (unsigned int)check_item->lvalue, authreq->name);
                      }
@@ -1355,7 +1371,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
                      retval = check_maxtraffic(auth_name,check_item->lvalue,MONTH_LIMIT);
                      if (retval != 0) {
                          result = -2;
-                         sprintf(umsg, "Maximum allowed monthly traffic size reached (%d KB)\r\n", (unsigned int)check_item->lvalue);
+                         snprintf(umsg,sizeof(umsg),"Maximum allowed monthly traffic size reached (%d KB)\r\n", (unsigned int)check_item->lvalue);
                          user_msg=umsg;
                          log_err("Maximum allowed monthly traffic size reached (%d KB) for '%s'\r\n", (unsigned int)check_item->lvalue, authreq->name);
                      }
@@ -1365,7 +1381,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
                      retval = check_maxtraffic(auth_name,check_item->lvalue,YEAR_LIMIT);
                      if (retval != 0) {
                          result = -2;
-                         sprintf(umsg, "Maximum allowed yearly traffic size reached (%d KB)\r\n", (unsigned int)check_item->lvalue);
+                         snprintf(umsg,sizeof(umsg),"Maximum allowed yearly traffic size reached (%d KB)\r\n", (unsigned int)check_item->lvalue);
                          user_msg=umsg;
                          log_err("Maximum allowed yearly traffic size reached (%d KB) for '%s'\r\n", (unsigned int)check_item->lvalue, authreq->name);
                      }
@@ -1548,7 +1564,7 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
 #endif /* ACTIVCARD */
   	case PW_AUTHTYPE_NONE:
   		/* No Password or Auth-Type found in check-items */
-  		__debug("entry for user \"%s\" has no Password or Auth-Type check-item\n",authreq->name);
+  		debug("entry for user \"%s\" has no Password or Auth-Type check-item\n",authreq->name);
   		result = 0;
   		break;
 
@@ -1581,7 +1597,8 @@ int rad_authenticate(AUTH_REQ *authreq,int activefd)
   *
   *************************************************************************/
 
-void send_reject(AUTH_REQ *authreq,char *msg,int activefd)
+void 
+send_reject(AUTH_REQ *authreq,char *msg,int activefd)
 {
   u_char			code;
   int			total_length;
@@ -1589,7 +1606,7 @@ void send_reject(AUTH_REQ *authreq,char *msg,int activefd)
   code = PW_AUTHENTICATION_REJECT;
   report[RR_REJECT]++;
 
-  __debug("sending reject to %s\n", req2strp(authreq));
+  debug("sending reject to %s\n", req2strp(authreq));
   total_length = build_packet(authreq,(VALUE_PAIR *)NULL,msg,code,
                               FW_REPLY,send_buffer,sizeof(send_buffer));
 
@@ -1607,7 +1624,8 @@ void send_reject(AUTH_REQ *authreq,char *msg,int activefd)
   *
   *************************************************************************/
 
-void send_challenge(AUTH_REQ *authreq,char *msg,char *state,int activefd)
+void 
+send_challenge(AUTH_REQ *authreq,char *msg,char *state,int activefd)
 {
   VALUE_PAIR *reply;
   int len;
@@ -1629,7 +1647,7 @@ void send_challenge(AUTH_REQ *authreq,char *msg,char *state,int activefd)
   	reply = (VALUE_PAIR *)NULL;
   }
 
-  __debug("sending challenge to %s\n", req2strp(authreq));
+  debug("sending challenge to %s\n", req2strp(authreq));
 
   total_length = build_packet(authreq,reply,msg,PW_ACCESS_CHALLENGE,FW_REPLY,send_buffer,sizeof(send_buffer));
 
@@ -1646,7 +1664,8 @@ void send_challenge(AUTH_REQ *authreq,char *msg,char *state,int activefd)
   *
   *************************************************************************/
 
-void send_accept(AUTH_REQ *authreq,VALUE_PAIR *reply,char *msg,int activefd)
+void 
+send_accept(AUTH_REQ *authreq,VALUE_PAIR *reply,char *msg,int activefd)
 {
   VALUE_PAIR		*menu_attr;
   char			state_value[120];
@@ -1662,7 +1681,7 @@ void send_accept(AUTH_REQ *authreq,VALUE_PAIR *reply,char *msg,int activefd)
 
   report[RR_ACCEPT]++;
 
-  __debug("sending accept to %s\n", req2strp(authreq));
+  debug("sending accept to %s\n", req2strp(authreq));
 
   total_length = build_packet(authreq,reply,msg,PW_AUTHENTICATION_ACK,FW_REPLY,send_buffer,sizeof(send_buffer));
 
@@ -1684,8 +1703,8 @@ void send_accept(AUTH_REQ *authreq,VALUE_PAIR *reply,char *msg,int activefd)
   *
   *************************************************************************/
 
-int build_packet(AUTH_REQ*authreq,VALUE_PAIR*reply,char*msg,u_char code,
-  	 int forward,u_char*buffer,size_t buflen )
+int 
+build_packet(AUTH_REQ*authreq,VALUE_PAIR*reply,char*msg,u_char code,int forward,u_char*buffer,size_t buflen )
 {
   AUTH_HDR		*auth;
   VALUE_PAIR		*item;
@@ -1728,6 +1747,9 @@ int build_packet(AUTH_REQ*authreq,VALUE_PAIR*reply,char*msg,u_char code,
                  }
   	switch(reply->type) {
 
+#if defined(ASCEND_BINARY)
+	case PW_TYPE_ABINARY:
+#endif
   	case PW_TYPE_STRING:
   		len = reply->lvalue;
   		if (len > AUTH_STRING_LEN) {
@@ -1853,7 +1875,8 @@ int build_packet(AUTH_REQ*authreq,VALUE_PAIR*reply,char*msg,u_char code,
   *
   *************************************************************************/
 
-char * decrypt_password(AUTH_REQ *authreq,char *secret)
+char * 
+decrypt_password(AUTH_REQ *authreq,char *secret)
 {
   VALUE_PAIR 	*auth_item;
   int		i;
@@ -1917,7 +1940,8 @@ char * decrypt_password(AUTH_REQ *authreq,char *secret)
   *
   *************************************************************************/
 
-char * encrypt_password(AUTH_REQ *authreq,char *secret)
+char * 
+encrypt_password(AUTH_REQ *authreq,char *secret)
 {
   VALUE_PAIR 	*auth_item;
   int		i;
@@ -1976,7 +2000,8 @@ char * encrypt_password(AUTH_REQ *authreq,char *secret)
   *
   *************************************************************************/
 
-void calc_digest(u_char *digest,AUTH_REQ *authreq,u_char *secret)
+void 
+calc_digest(u_char *digest,AUTH_REQ *authreq,u_char *secret)
 {
   u_char	buffer[128];
   int	secretlen;
@@ -2001,7 +2026,8 @@ void calc_digest(u_char *digest,AUTH_REQ *authreq,u_char *secret)
   *
   *************************************************************************/
 
-void calc_next_digest(u_char*digest,u_char*secret,u_char*vector)
+void 
+calc_next_digest(u_char*digest,u_char*secret,u_char*vector)
 {
   u_char	buffer[128];
   int	secretlen;
@@ -2024,7 +2050,8 @@ void calc_next_digest(u_char*digest,u_char*secret,u_char*vector)
   *
   *************************************************************************/
 
-char* client_hostname(UINT4 ipaddr)
+char* 
+client_hostname(UINT4 ipaddr)
 {
   u_char secret[64];
   char	hostnm[MAX_HOST_SIZE];
@@ -2049,7 +2076,8 @@ char* client_hostname(UINT4 ipaddr)
   *
   *************************************************************************/
 
-int find_client(UINT4 ipaddr,char*secret,int secretlen,char*hostnm,size_t hostnmlen)
+int 
+find_client(UINT4 ipaddr,char*secret,int secretlen,char*hostnm,size_t hostnmlen)
 {
   GDBM_FILE       db;
   char		buffer[MAX_LINE_SIZE];
@@ -2125,7 +2153,8 @@ int find_client(UINT4 ipaddr,char*secret,int secretlen,char*hostnm,size_t hostnm
   *
   *************************************************************************/
 
-int update_clients(void)
+int 
+update_clients(void)
 {
   static time_t	last_update_time;
   struct stat 	statbuf;
@@ -2208,7 +2237,7 @@ int update_clients(void)
              log_err("Error: could not move client cache file %s to %s,"
                      "error %d\n",newcache,oldcache,errno);
              return(-1);
-     	} else { __debug("updated client cache with %d clients\n",nclients); }
+     	} else { debug("updated client cache with %d clients\n",nclients); }
 
   if (rcode == 0) last_update_time = statbuf.st_mtime;
   return(rcode);
@@ -2222,7 +2251,8 @@ int update_clients(void)
   *
   *************************************************************************/
 
-void debug_pair(VALUE_PAIR * pair)
+void 
+debug_pair(VALUE_PAIR * pair)
 {
   if(debug_flag) { fprint_attr_val(stdout, pair); }
 }
@@ -2235,7 +2265,8 @@ void debug_pair(VALUE_PAIR * pair)
   *
   *************************************************************************/
 
-void usage(void)
+void 
+usage(void)
 {
   fprintf(stderr, "Usage: %s\n", progname);
   fprintf(stderr, " [-a <acct_dir>] set accounting directory\n");
@@ -2280,7 +2311,8 @@ void usage(void)
   *
   *************************************************************************/
 
-int config_init(void)
+int 
+config_init(void)
 {
   DICT_VALUE	*dval;
   DICT_VALUE	*dict_valfind();
@@ -2310,7 +2342,8 @@ int config_init(void)
   *
   *************************************************************************/
 
-int set_expiration(VALUE_PAIR*user_check,UINT4 expiration)
+int 
+set_expiration(VALUE_PAIR*user_check,UINT4 expiration)
 {
   VALUE_PAIR	*exppair;
   VALUE_PAIR	*prev;
@@ -2361,7 +2394,8 @@ int set_expiration(VALUE_PAIR*user_check,UINT4 expiration)
   *
   *************************************************************************/
 
-int pw_expired(UINT4 exptime)
+int 
+pw_expired(UINT4 exptime)
 {
   struct timeval	tp;
   struct timezone	tzp;
@@ -2395,7 +2429,8 @@ int pw_expired(UINT4 exptime)
   *
   *************************************************************************/
 
-VALUE_PAIR* get_attribute(VALUE_PAIR*value_list,int attribute)
+VALUE_PAIR* 
+get_attribute(VALUE_PAIR*value_list,int attribute)
 {
   while(value_list != (VALUE_PAIR *)NULL) {
   	if(value_list->attribute == attribute) {
@@ -2407,7 +2442,8 @@ VALUE_PAIR* get_attribute(VALUE_PAIR*value_list,int attribute)
 }
 
 
-void sig_fatal(int sig)
+void 
+sig_fatal(int sig)
 {
   if(acct_pid > 0) {
   	kill(acct_pid, SIGKILL);
@@ -2420,12 +2456,14 @@ void sig_fatal(int sig)
   rad_exit(1);
 }
 
-void sig_hup(int sig)
+void 
+sig_hup(int sig)
 {
   return;
 }
 
-void sig_usr1(int sig)
+void 
+sig_usr1(int sig)
 {
   extern int debug_flag;
 
@@ -2435,7 +2473,8 @@ void sig_usr1(int sig)
   return;
 }
 
-void sig_usr2(int sig)
+void 
+sig_usr2(int sig)
 {
   extern int debug_flag;
 
@@ -2447,7 +2486,8 @@ void sig_usr2(int sig)
   return;
 }
 
-void rad_exit(int rc)
+void 
+rad_exit(int rc)
 {
 #ifdef SECURID
   AUTH_REQ	*curreq;
@@ -2481,7 +2521,8 @@ void rad_exit(int rc)
   exit(rc);
 }
 
-void log_counters(void)
+void 
+log_counters(void)
 {
   extern int report[];
 
