@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: radlast.c,v 1.8 2004/07/01 13:57:55 flovergine Exp $";
+static char rcsid[] = "$Id: radlast.c 75 2004-08-02 18:40:07Z flovergine $";
 
 # define __MAIN__
 
@@ -20,7 +20,8 @@ char username[USERNAME_MAX];
 static int brief = 0;
 static int extended = 0;
 
-static const char *port_type_str(int type)
+static const char *
+port_type_str(int type)
 {
     switch (type) {
 	case 0:
@@ -40,7 +41,8 @@ static const char *port_type_str(int type)
     return "Unknown";
 }
 
-static const char * proto_type_str(int proto)
+static const char * 
+proto_type_str(int proto)
 {
     switch (proto) {
 	case P_TELNET:
@@ -65,7 +67,8 @@ static const char * proto_type_str(int proto)
 }
 
 
-static int parse_width(char **format)
+static int 
+parse_width(char **format)
 {
   int width=0;
   char *endstr;
@@ -108,7 +111,8 @@ static int parse_width(char **format)
  * 	the same sense of printf() format value.
  */
 
-static void parse_formatstr( char *formatstr,radlast rl )
+static void 
+parse_formatstr( char *formatstr,radlast rl )
 {
   char port_str[100];
   char nas_ip[100];
@@ -260,7 +264,8 @@ static void parse_formatstr( char *formatstr,radlast rl )
  *		\n \t \r \\ As obvious :-)
  */
 
-static void parse_header( char *header )
+static void 
+parse_header( char *header )
 {
    while (*header) {
       switch (*header) {
@@ -291,7 +296,8 @@ static void parse_header( char *header )
     }
 }
 
-static void print_entry(radlast rad_last)
+static void 
+print_entry(radlast rad_last)
 {
   if (extended)
     if (brief) parse_formatstr("%l/%p/%a/%k/%c/%d/%T/%I/%O/%M/%s/%S/%A/%#\n",
@@ -325,7 +331,8 @@ static void print_entry(radlast rad_last)
                     "Session-Time = %T\n",rad_last);
 }
 
-static void radlast_usage(void)
+static void 
+radlast_usage(void)
 {
     printf("\nUsage: %s <option>\n\nValid options are:\n", progname);
     printf("\t-a <acct_dir>\tthe radius accounting files directory\n");
@@ -335,7 +342,6 @@ static void radlast_usage(void)
     printf("\t-u <username>\tget username database entry\n");
     printf("\t-f <filename>\tuse this radlast logfile instead\n");
     printf("\t-h\t\tthis help screen\n");
-    printf("\t-n <num>\tPrint only <num> entries\n");
     printf("\t-m <month>\treport statistics for <month>\n");
     printf("\t-y <year>\treport statistics for <year>\n");
     printf("\t-b\t\tsingle row output\n");
@@ -343,12 +349,14 @@ static void radlast_usage(void)
     exit(-1);
 }
 
-static void fatal_func(const char *msg) {
+static void 
+fatal_func(const char *msg) {
     fprintf(stderr, "FATAL ERROR: %s\n",msg);
     return;
 }
 
-int main(int argc, char **argv)
+int 
+main(int argc, char **argv)
 {
     radlast rad_last;
     int fd;
@@ -367,7 +375,6 @@ int main(int argc, char **argv)
     char *format=NULL;
     char *header=NULL;
     extern char *optarg;
-    int num = 0, count = 0;
     
     crt_time = time(NULL);
     time_info = localtime(&crt_time);
@@ -380,7 +387,7 @@ int main(int argc, char **argv)
     progname = argv[0];
     radacct_dir = RADACCT_DIR;
     
-    while ((flag = getopt(argc, argv, "a:F:H:cu:f:by:m:xhn:")) != EOF) {
+    while ((flag = getopt(argc, argv, "a:F:H:cu:f:by:m:xh")) != EOF) {
 	char *cp;
 	switch (flag) {
 	    case 'a':
@@ -410,13 +417,6 @@ int main(int argc, char **argv)
             case 'b':
 		brief++;
 		break;
-            case 'n':
-                num = strtol(optarg, &cp, 10);
-		if (*cp) {
-                   fatal_func("number of entries must be an integer\n");
-                   radlast_usage();
-		}
-                break;
 	    case 'y':
 		if (file_arg) {
                     fatal_func("you can not specify a year and a filename");
@@ -471,8 +471,7 @@ int main(int argc, char **argv)
 	    seekpos = lseek(fd, -sizeof(radlast), SEEK_END);
 	if ( format != NULL && header != NULL ) parse_header(header); 
 	while ((seekpos >= 0) &&
-	       read(fd, &rad_last, sizeof(radlast)) == sizeof(radlast) &&
-	       (num == 0 || count < num)) {
+	       read(fd, &rad_last, sizeof(radlast)) == sizeof(radlast)) {
 	    if (user_arg && strncmp(username, rad_last.login, USERNAME_MAX)) {
 		memset(&rad_last, 0, sizeof(rad_last));
 		if (!cronologic)
@@ -484,8 +483,6 @@ int main(int argc, char **argv)
 	    memset(&rad_last, 0, sizeof(rad_last));
 	    if (!cronologic)
 		seekpos = lseek(fd, -2*sizeof(radlast), SEEK_CUR);
-            if (num)
-		count++;
 	}
     } else {
 	fprintf(stderr, "Cannot open the radlast log file: %s\n",filename);
@@ -494,7 +491,8 @@ int main(int argc, char **argv)
     exit(0);
 }
 
-void rad_exit(int code)
+void 
+rad_exit(int code)
 {
  	exit(code);
 }
