@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: radlist.c,v 1.8 2003/07/08 13:20:42 kiavik Exp $";
+static char rcsid[] = "$Id: radlist.c 75 2004-08-02 18:40:07Z flovergine $";
     
 #define __MAIN__
 
@@ -32,12 +32,14 @@ static char hdrstr[] = "  Username   Sess Logs    OnLine       Input/Output/Tota
 
 */
 
-UINT4 get_daily_online( user_entry *ue,int month,int day )
+UINT4 
+get_daily_online( user_entry *ue,int month,int day )
 {
   return ue->day[month][day].on_line;
 }
 
-UINT4 get_monthly_online( user_entry *ue,int month,int day )
+UINT4 
+get_monthly_online( user_entry *ue,int month,int day )
 {
   int i;
   UINT4 sum=0;
@@ -46,7 +48,8 @@ UINT4 get_monthly_online( user_entry *ue,int month,int day )
   return sum;
 }
 
-UINT4 get_yearly_online( user_entry *ue,int month,int day )
+UINT4 
+get_yearly_online( user_entry *ue,int month,int day )
 {
   int i, j;
   UINT4 sum=0;
@@ -56,12 +59,14 @@ UINT4 get_yearly_online( user_entry *ue,int month,int day )
   return sum;
 }
 
-UINT4 get_daily_itraffic( user_entry *ue,int month,int day )
+UINT4 
+get_daily_itraffic( user_entry *ue,int month,int day )
 {
   return ue->day[month][day].input_octets;
 }
 
-UINT4 get_monthly_itraffic( user_entry *ue,int month,int day )
+UINT4 
+get_monthly_itraffic( user_entry *ue,int month,int day )
 {
   int i;
   UINT4 sum=0;
@@ -70,7 +75,8 @@ UINT4 get_monthly_itraffic( user_entry *ue,int month,int day )
   return sum;
 }
 
-UINT4 get_yearly_itraffic( user_entry *ue,int month,int day )
+UINT4 
+get_yearly_itraffic( user_entry *ue,int month,int day )
 {
   int i, j;
   UINT4 sum=0;
@@ -82,12 +88,14 @@ UINT4 get_yearly_itraffic( user_entry *ue,int month,int day )
 
 
 
-UINT4 get_daily_otraffic( user_entry *ue,int month,int day )
+UINT4 
+get_daily_otraffic( user_entry *ue,int month,int day )
 {
   return ue->day[month][day].output_octets;
 }
 
-UINT4 get_monthly_otraffic( user_entry *ue,int month,int day )
+UINT4 
+get_monthly_otraffic( user_entry *ue,int month,int day )
 {
   int i;
   UINT4 sum=0;
@@ -96,7 +104,8 @@ UINT4 get_monthly_otraffic( user_entry *ue,int month,int day )
   return sum;
 }
 
-UINT4 get_yearly_otraffic( user_entry *ue,int month,int day )
+UINT4 
+get_yearly_otraffic( user_entry *ue,int month,int day )
 {
   int i, j;
   UINT4 sum=0;
@@ -108,12 +117,14 @@ UINT4 get_yearly_otraffic( user_entry *ue,int month,int day )
 
 
 
-UINT4 get_daily_nr_logins( user_entry *ue,int month,int day )
+UINT4 
+get_daily_nr_logins( user_entry *ue,int month,int day )
 {
   return ue->day[month][day].nr_logins;
 }
 
-UINT4 get_monthly_nr_logins( user_entry *ue,int month,int day )
+UINT4 
+get_monthly_nr_logins( user_entry *ue,int month,int day )
 {
   int i;
   UINT4 sum=0;
@@ -122,7 +133,8 @@ UINT4 get_monthly_nr_logins( user_entry *ue,int month,int day )
   return sum;
 }
 
-UINT4 get_yearly_nr_logins( user_entry *ue,int month,int day )
+UINT4 
+get_yearly_nr_logins( user_entry *ue,int month,int day )
 {
   int i, j;
   UINT4 sum=0;
@@ -157,7 +169,8 @@ fptr get_stat[4][3] = {
 };
 
 
-static void radlist_usage(void)
+static void 
+radlist_usage(void)
 {
     printf("\nUsage: %s <option>\nValid options are:\n", progname);
     printf("\t-s\t\tlist stats\n");
@@ -178,7 +191,8 @@ static void radlist_usage(void)
 }
 
 
-static const char * proto_type_str(int proto)
+static const char * 
+proto_type_str(int proto)
 {
     switch (proto) {
         case P_TELNET:
@@ -202,23 +216,26 @@ static const char * proto_type_str(int proto)
     return "UNK";
 }
 
-static void print_error(char * fmt,va_list args) 
+static void 
+print_error(char * fmt,va_list args) 
 {
   vfprintf( stderr,fmt,args ); 
   return;
 }
 
-static void error(char *fmt,...)
+static void 
+error(char *fmt,...)
 {
   va_list arg;
 
   va_start(arg,fmt);
   fprintf( stderr,"%s: ",progname );
   print_error(fmt,arg);
-  va_end(arg);
+  va_end(fmt);
 }
 
-static int parse_width(char **format)
+static int 
+parse_width(char **format)
 {
   int width=0;
   char *endstr;
@@ -231,11 +248,8 @@ static int parse_width(char **format)
   return width;
 }
 
-static void parse_format(char *format,
-			 char *entry, 
-			 user_entry *tmp,
-			 int datasize,
-			 int mday,int month,int stat)
+static void 
+parse_format(char *format, char *entry, user_entry *tmp, int datasize, int mday,int month,int stat)
 {
     UINT4 on_line;
     UINT4 itraffic,otraffic;
@@ -347,12 +361,8 @@ static void parse_format(char *format,
     }
 }
 
-static void parse_pformat(char *format,
-			 char *entry, 
-			 user_entry *tmp,
-			 int datasize,
-			 int mday,int month,int stat,
-			 port_entry *tpe, int number)
+static void 
+parse_pformat(char *format, char *entry, user_entry *tmp, int datasize, int mday,int month,int stat, port_entry *tpe, int number)
 {
     static char *months[] = { "Jan", "Feb", "Mar", "Apr", "May", "Jun",
 		              "Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
@@ -458,11 +468,8 @@ static void parse_pformat(char *format,
     }
 }
 
-static void print_user_entry(char *format,
-			     char *entry, 
-			     user_entry *tmp,
-			     int datasize,
-			     int mday,int month,int stat)
+static void 
+print_user_entry(char *format, char *entry, user_entry *tmp, int datasize, int mday,int month,int stat)
 {
     if ((tmp->logins == 0) && !dostat ) {
       if ( username != NULL ) error("user '%s' not logged\n",username);
@@ -541,7 +548,8 @@ static void print_user_entry(char *format,
 
 
 
-int main(int argc, char ** argv)
+int 
+main(int argc, char ** argv)
 {
     GDBM_FILE dbf;
     datum key, content, nextkey;
@@ -725,5 +733,6 @@ int main(int argc, char ** argv)
     return 0;
 }
 
-void rad_exit(int code)
+void 
+rad_exit(int code)
 { exit(code); }
