@@ -40,8 +40,7 @@ The other flags work as follows:
 
 */
 
-static char rcsid[] =
-"$Id: radtest.c,v 1.3 2002/03/05 19:17:57 kiavik Exp $ Copyright 1999-2002 Francesco P. Lovergine";
+static char rcsid[] = "$Id: radtest.c 83 2004-08-28 13:32:47Z flovergine $ Copyright (C) 1999-2004 Francesco P. Lovergine";
 
 
 #include "yard.h"
@@ -69,35 +68,36 @@ char	*radius_dir = ".";
 char	*radius_log = "/dev/tty";
 UINT4	now = 0;
 
+int
 main(int argc,char **argv)
 {
 	static AUTH_HDR		*ah;
 	static AUTH_REQ		*authreq;
-	static VALUE_PAIR		*pair;
+	static VALUE_PAIR	*pair;
 	static char		*called_id;
 	static char		*calling_id;
-	static char			argnum;
-	static char			argval;
-	static fd_set			fdset;
-	static int			acct_flag;
-	static int			count;
-	static int			frame_flag;
-	static int			host;
-	static int			i;
-	static int			len;
-	static int			rc;
-	static int			sa_len;
-	static int			service_type;
-	static int			val;
-	static int			verbose_flag;
-	static struct			sockaddr_in sa_ihd;
-	static struct			timeval tv;
+	static char		argnum;
+	static char		argval;
+	static fd_set		fdset;
+	static int		acct_flag;
+	static int		count;
+	static int		frame_flag;
+	static int		host;
+	static int		i;
+	static int		len;
+	static int		rc;
+	static int		sa_len;
+	static int		service_type;
+	static int		val;
+	static int		verbose_flag;
+	static struct		sockaddr_in sa_ihd;
+	static struct		timeval tv;
 	static struct servent *	svp;
-	static u_char			*cp;
-	static u_char			alen;
-	static u_char			id;
-	static u_short			radius_port;
-        static u_short                 lport;
+	static u_char		*cp;
+	static u_char		alen;
+	static u_char		id;
+	static u_short		radius_port;
+        static u_short          lport;
 
 	static char passwd[AUTH_PASS_LEN];
 	static char md5_buf[1024];
@@ -218,9 +218,11 @@ main(int argc,char **argv)
 			if(argc < 2) {
 				usage();
 			}
-			strcpy(u_name,*argv);
+			strncpy(u_name,*argv,sizeof(u_name)-1);
+			u_name[sizeof(u_name)-1]='\0';
 			argv++;
-			strcpy(u_passwd,*argv);
+			strncpy(u_passwd,*argv,sizeof(u_passwd)-1);
+			u_passwd[sizeof(u_passwd)-1]='\0';
 			argv++;
 			argc -= 2;
 			break;
@@ -334,7 +336,8 @@ main(int argc,char **argv)
 
 		memset(passwd, 0, AUTH_PASS_LEN);
 		memcpy(passwd, u_passwd, u_passwd_len);
-		strcpy(md5_buf, secret);
+		strncpy(md5_buf, secret, sizeof(md5_buf)-1);
+		md5_buf[sizeof(md5_buf)-1]='\0';
 		memcpy(md5_buf + secret_len, ah->vector, AUTH_VECTOR_LEN);
 		md5_calc(cp, md5_buf, secret_len + AUTH_VECTOR_LEN);
 		for (i = 0; i < AUTH_PASS_LEN; i++) {
@@ -508,13 +511,8 @@ main(int argc,char **argv)
  *
  *************************************************************************/
 
-AUTH_REQ	*
-radrecv(host, udp_port, secret, buffer, length)
-UINT4	host;
-u_short	udp_port;
-char	*secret;
-u_char	*buffer;
-int	length;
+AUTH_REQ *
+radrecv( UINT4 host, u_short udp_port, char *secret, u_char *buffer,int length )
 {
 	u_char		*ptr;
 	char		*bufalloc();
@@ -560,7 +558,7 @@ int	length;
 		return((AUTH_REQ *)NULL);
 	}
 
-	__debug("message received from %s/%d.%d code=%d, length=%d\n",
+	debug("message received from %s/%d.%d code=%d, length=%d\n",
 		ipaddr2strp(host), udp_port, auth->id, auth->code, totallen);
 
 	if (debug_flag > 1) {
@@ -603,11 +601,12 @@ int	length;
 		pair = pairalloc("radrecv");
 
 		if((attr = dict_attrget(attribute)) == (DICT_ATTR *)NULL) {
-			sprintf(pair->name,"Unknown-%d",attribute);
+			snprintf(pair->name,VALUE_PAIR_NAME_LEN,"Unknown-%d",attribute);
 			pair->attribute = attribute;
 			pair->type = PW_TYPE_STRING;
 		} else {
-			strcpy(pair->name, attr->name);
+			strncpy(pair->name, attr->name, VALUE_PAIR_NAME_LEN-1 );
+			pair->name[VALUE_PAIR_NAME_LEN-1]='\0';
 			pair->attribute = attr->value;
 			pair->type = attr->type;
 		}
@@ -629,10 +628,11 @@ int	length;
 				pair->vendor = vendor;
 				pair->vsattribute = vsa;
 				if((attr = dict_vsattrget(vendor,vsa)) != (DICT_ATTR *)NULL) {
-					strcpy(pair->name, attr->name);
+					strncpy(pair->name, attr->name, VALUE_PAIR_NAME_LEN-1 );
+					pair->name[VALUE_PAIR_NAME_LEN-1]='\0';
 					pair->type = attr->type;
 				} else {
-					sprintf(pair->name,"Vendor-Specific-%d-%d",vendor,vsa);
+					snprintf(pair->name,VALUE_PAIR_NAME_LEN,"Vendor-Specific-%d-%d",vendor,vsa);
 					pair->type = PW_TYPE_STRING;
 				}
 			}
@@ -641,6 +641,9 @@ int	length;
 		switch(pair->type) {
 
 		case PW_TYPE_STRING:
+#if defined(ASCEND_BINARY)
+		case PW_TYPE_ABINARY:
+#endif
 			memcpy(pair->strvalue, ptr, attrlen);
 			pair->strvalue[attrlen] = '\0';
 			pair->lvalue = attrlen;
@@ -668,7 +671,7 @@ int	length;
 			break;
 
 		default:
-			__debug("    %s (Unknown Type %d)\n",
+			debug("    %s (Unknown Type %d)\n",
 				attr->name,attr->type);
 			pairfree(pair,"radrecv");
 			break;
@@ -688,22 +691,21 @@ int	length;
 }
 
 void
-usage()
+usage(void)
 {
 	printf("usage: %s -d called_id -f -g calling_id -h -i id -p port -s secret -t type -v -x -u username password\n", progname);
 	exit(0);
 }
 
 void
-rad_exit(rc)
-int rc;
+rad_exit(int rc)
 {
 	exit(rc);
 }
 
 void
-version()
+version(void)
 {
-	printf("%s 1.0 1999/6/15\n", progname);
+	printf("%s $Date: 2004-08-28 15:32:47 +0200 (sab, 28 ago 2004) $\n", progname);
 	exit(0);
 }
