@@ -25,11 +25,11 @@
  * distributed with this release.
  */
 
-static char rcsid[] = "$Id: radwatch.c,v 1.6 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: radwatch.c 81 2004-08-27 21:45:17Z flovergine $";
 
 #include "yard.h"
 
-#define REVISION    "$Revision: 1.6 $"
+#define REVISION    "$Revision: 81 $"
 #define RADWATCH   "radwatch.conf"	/* radwatch config file */
 
 #ifndef min
@@ -92,10 +92,8 @@ static USER_TIME *user_time_head = NULL;
 
 /* Inserts a new entry into the linked list of the known users. The space is */
 /* malloced and should be free'd later (using empty_user_time_list()) */
-static void add_user_time_list(char *username,
-			       struct period period,
-			       int restriction,
-			       int counted)
+static void 
+add_user_time_list(char *username, struct period period, int restriction, int counted)
 {
     USER_TIME *ut;
 
@@ -126,7 +124,8 @@ static void add_user_time_list(char *username,
 	
 /* This function traverse the linked list of the known users and free() */
 /* the space used by it's elements. */
-static void empty_user_time_list(void)
+static void 
+empty_user_time_list(void)
 {
     USER_TIME *ut;
     
@@ -142,7 +141,8 @@ static void empty_user_time_list(void)
 }
 
 /* Open the configuration file */
-static void open_conf_file(void)
+static void 
+open_conf_file(void)
 {
     static char filename[PATH_MAX];
 
@@ -156,7 +156,8 @@ static void open_conf_file(void)
 }
 
 /* Close the configuration file */
-static void close_conf_file(void)
+static void 
+close_conf_file(void)
 {
     if (ports)
 	fclose (ports);
@@ -167,7 +168,8 @@ static void close_conf_file(void)
 /* Reads and parses the next valid config line from the program's */
 /* configuration file. All the data it returns it is statically */
 /* allocated, no need to be free'd. The parser _should_ work... */
-static struct conf_line *get_conf_line(void)
+static struct conf_line *
+get_conf_line(void)
 {
     static	struct	conf_line  conf_line;	/* static struct to point to         */
     static	char	buf[BUFSIZ];	/* some space for stuff              */
@@ -366,7 +368,8 @@ static struct conf_line *get_conf_line(void)
     return NULL; /* NOT REACHEAD... */
 }
 
-int unix_group(const char *name, const char *group)
+int 
+unix_group(const char *name, const char *group)
 {
     struct passwd       *pwd;
     char                **gr_mem;
@@ -374,12 +377,12 @@ int unix_group(const char *name, const char *group)
 
     /* Get encrypted password from password file */
     if((pwd = getpwnam(name)) == NULL) {
-	__debug("unix_group: getpwnam for <%s> failed\n", name);
+	debug("unix_group: getpwnam for <%s> failed\n", name);
 	return(0);
     }
 
     if((gr_ent = getgrnam(group)) == NULL) {
-	__debug("unix_group: getgrnam(%s) for <%s> failed\n", group,name);
+	debug("unix_group: getgrnam(%s) for <%s> failed\n", group,name);
 	return(0);
     }
 
@@ -406,7 +409,8 @@ int unix_group(const char *name, const char *group)
  *      searched from the beginning, so the entries are treated as
  *      an ordered list.
  */
-static struct conf_line *get_user_line (const char *user)
+static struct conf_line *
+get_user_line (const char *user)
 {
     int i;
     struct	conf_line	*conf_line;
@@ -438,7 +442,8 @@ static struct conf_line *get_user_line (const char *user)
  * given to time frames, return the amount in secs for the common
  * period
  */
-static int common_time(struct period time1, struct period time2)
+static int 
+common_time(struct period time1, struct period time2)
 {
     time_t t1, t2;
 
@@ -452,9 +457,8 @@ static int common_time(struct period time1, struct period time2)
     return (int)(t2 - t1);
 }
 
-static int get_period(struct period *period,
-		      struct time_frame *tf,
-		      time_t when)
+static int 
+get_period(struct period *period,struct time_frame *tf,time_t when)
 {
     struct tm *tm;
     time_t zerotime;
@@ -487,7 +491,8 @@ static int get_period(struct period *period,
  * This is a debugging function. It prints out the list of the users,
  * along with their time and quota.
  */
-static void print_user_list(void)
+static void 
+print_user_list(void)
 {
     USER_TIME *ut;
  
@@ -510,7 +515,8 @@ static void print_user_list(void)
  * and the time of the entry matches the window time period recorded
  * as restricted time for this user, count that time in...
  */
-static void update_user_time(radlast rl)
+static void 
+update_user_time(radlast rl)
 {
     USER_TIME *ut;
     int t;
@@ -540,7 +546,8 @@ static void update_user_time(radlast rl)
  * get_user_time
  * returns the used time by the user withing a certain frame period 
  */
-static int parse_radacct_file(void)
+static int 
+parse_radacct_file(void)
 {
     int fd;
     char filename[PATH_MAX];
@@ -586,7 +593,8 @@ static int parse_radacct_file(void)
 /*
  * Print a short (and hopefully clear) usage screen. 
  */
-static void radwatch_usage(void)
+static void 
+radwatch_usage(void)
 {
     printf("\n%s version %s\n", progname, REVISION);
     printf("Usage: %s <option>\nValid options are:\n", progname);
@@ -607,7 +615,8 @@ static void radwatch_usage(void)
  * will be hurt so bad at this stage.... 
  */
 
-static GDBM_FILE open_radlist(void)
+static GDBM_FILE 
+open_radlist(void)
 {
     GDBM_FILE dbf;
     char db_name[PATH_MAX];
@@ -633,7 +642,8 @@ static GDBM_FILE open_radlist(void)
  * Well, this programs accepts arguments and flags... 
  * Isn't it cool ? :-) 
  */
-static void parse_args(int argc, char **argv)
+static void 
+parse_args(int argc, char **argv)
 {
     int flag;
     while ((flag = getopt(argc, argv, "ma:d:xh")) != EOF) {
@@ -668,12 +678,8 @@ static void parse_args(int argc, char **argv)
  *   0 = okay
  * < 0 = time exceeded 
  */
-static void insert_user_in_list(char *username,
-				struct time_frame *tf,
-				time_t when,
-				int max_seconds,
-				user_entry *ue,
-				int ue_size)
+static void 
+insert_user_in_list(char *username, struct time_frame *tf, time_t when, int max_seconds, user_entry *ue, int ue_size)
 {
     int usr_time = 0;
     struct period period;
@@ -708,7 +714,8 @@ static void insert_user_in_list(char *username,
  * Opens the radius stop list file, in the mode supplied by argument.
  * Returns the result of the call to fopen
  */
-static FILE *open_radstop_file(const char * mode)
+static FILE *
+open_radstop_file(const char * mode)
 {
     FILE *fp;
     char filename[PATH_MAX];
@@ -723,7 +730,8 @@ static FILE *open_radstop_file(const char * mode)
  * Returns true if the account is locked. 
  * used by the lock_accounts function. 
  */
-static int is_locked(char *user)
+static int 
+is_locked(char *user)
 {
     FILE *fp;
     char buffer[1024];
@@ -750,7 +758,8 @@ static int is_locked(char *user)
  * No checking for the previous existence in that file is done since this
  * test is supposed to be already done somewhere else
  */
-static void lock_account(char *user)
+static void 
+lock_account(char *user)
 {
     FILE *fp;
 
@@ -768,7 +777,8 @@ static void lock_account(char *user)
  * Iterate through the user list and check for over-quota accounts. If it
  * is not already locked, lock the account.
  */
-static void lock_accounts(void)
+static void 
+lock_accounts(void)
 {
     USER_TIME *ut;
     
@@ -793,7 +803,8 @@ static void lock_accounts(void)
  * Given an user, walks through the user_time list and see if this
  * user is over quota. 
  */
-static int over_quota(char *user)
+static int 
+over_quota(char *user)
 {
     USER_TIME *ut;
 
@@ -813,7 +824,8 @@ static int over_quota(char *user)
  * still match the restriction time criteria. If it does NOT, then
  * this user should not be black-listed anymore...
  */
-static void unlock_accounts(void)
+static void 
+unlock_accounts(void)
 {
     FILE *fo, *fn;
     char fileold[PATH_MAX], filenew[PATH_MAX];
@@ -877,7 +889,8 @@ static void unlock_accounts(void)
  * Overall, this is the idea of this program: unlock the accounts which are
  * no longer under quota constraints, and add the new ones after that.
  */
-static void check_user_times(void)
+static void 
+check_user_times(void)
 {
     if (debug_flag)
 	print_user_list();
@@ -901,7 +914,8 @@ static void check_user_times(void)
 /*
  * The Main Thing: make this program work.
  */
-int main(int argc, char ** argv)
+int 
+main(int argc, char ** argv)
 {
     GDBM_FILE dbf;
     datum key, content, nextkey;
@@ -1007,7 +1021,8 @@ int main(int argc, char ** argv)
     exit(0);
 }
 
-void rad_exit(int code)
+void 
+rad_exit(int code)
 {
         exit(code);
 }
