@@ -105,7 +105,8 @@ static void dopr_outch (char *buffer, size_t *currlen, size_t maxlen, char c );
 #define char_to_int(p) (p - '0')
 #define THEMAX(p,q) (((p) >= (q)) ? (p) : (q))
 
-static void dopr (char *buffer, size_t maxlen, const char *format, va_list args)
+static void 
+dopr(char *buffer, size_t maxlen, const char *format, va_list args)
 {
   char ch;
   long value;
@@ -358,8 +359,8 @@ static void dopr (char *buffer, size_t maxlen, const char *format, va_list args)
     buffer[maxlen - 1] = '\0';
 }
 
-static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
-		    char *value, int flags, int min, int max)
+static void 
+fmtstr (char *buffer, size_t *currlen, size_t maxlen,char *value, int flags, int min, int max)
 {
   int padlen, strln;     /* amount to pad */
   int cnt = 0;
@@ -397,8 +398,8 @@ static void fmtstr (char *buffer, size_t *currlen, size_t maxlen,
 
 /* Have to handle DP_F_NUM (ie 0x and 0 alternates) */
 
-static void fmtint (char *buffer, size_t *currlen, size_t maxlen,
-		    long value, int base, int min, int max, int flags)
+static void 
+fmtint (char *buffer, size_t *currlen, size_t maxlen,long value, int base, int min, int max, int flags)
 {
   int signvalue = 0;
   unsigned long uvalue;
@@ -487,7 +488,8 @@ static void fmtint (char *buffer, size_t *currlen, size_t maxlen,
   }
 }
 
-static long double abs_val (long double value)
+static long double 
+abs_val(long double value)
 {
   long double result = value;
 
@@ -497,7 +499,8 @@ static long double abs_val (long double value)
   return result;
 }
 
-static long double pow10 (int exp)
+static long double 
+pow10(int exp)
 {
   long double result = 1;
 
@@ -510,7 +513,8 @@ static long double pow10 (int exp)
   return result;
 }
 
-static long round (long double value)
+static long 
+round(long double value)
 {
   long intpart;
 
@@ -522,8 +526,8 @@ static long round (long double value)
   return intpart;
 }
 
-static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
-		   long double fvalue, int min, int max, int flags)
+static void 
+fmtfp (char *buffer, size_t *currlen, size_t maxlen,long double fvalue, int min, int max, int flags)
 {
   int signvalue = 0;
   long double ufvalue;
@@ -658,20 +662,23 @@ static void fmtfp (char *buffer, size_t *currlen, size_t maxlen,
   }
 }
 
-static void dopr_outch (char *buffer, size_t *currlen, size_t maxlen, char c)
+static void 
+dopr_outch (char *buffer, size_t *currlen, size_t maxlen, char c)
 {
   if (*currlen < maxlen)
     buffer[(*currlen)++] = c;
 }
 
-int vsnprintf (char *str, size_t count, const char *fmt, va_list args)
+int 
+vsnprintf (char *str, size_t count, const char *fmt, va_list args)
 {
   str[0] = 0;
   dopr(str, count, fmt, args);
   return(strlen(str));
 }
 
-int snprintf (char *str,size_t count,const char *fmt,...)
+int 
+snprintf (char *str,size_t count,const char *fmt,...)
 {
   VA_LOCAL_DECL;
     
@@ -688,7 +695,8 @@ int snprintf (char *str,size_t count,const char *fmt,...)
 #ifndef LONG_STRING
 #define LONG_STRING 1024
 #endif
-int main (void)
+int 
+main(void)
 {
   char buf1[LONG_STRING];
   char buf2[LONG_STRING];
