@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: users.c,v 1.5 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: users.c 80 2004-08-19 16:19:18Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -25,7 +25,8 @@ int 		db_index;
  *
  *************************************************************************/
 
-static void fieldcpy(char*string,char**uptr)
+static void 
+fieldcpy(char*string,char**uptr)
 {
 	char	*ptr;
 
@@ -67,8 +68,8 @@ static void fieldcpy(char*string,char**uptr)
  *
  *************************************************************************/
 
-int user_find(char*req_name, char*auth_name, VALUE_PAIR**check_pairs, 
-	      VALUE_PAIR**reply_pairs,USER_FILE user_desc)
+int 
+user_find(char*req_name, char*auth_name, VALUE_PAIR**check_pairs,VALUE_PAIR**reply_pairs,USER_FILE user_desc)
 {
 	VALUE_PAIR	*check_first;
 	VALUE_PAIR	*reply_first;
@@ -268,7 +269,8 @@ int user_find(char*req_name, char*auth_name, VALUE_PAIR**check_pairs,
  *
  *************************************************************************/
 
-int user_auth_name(char*rname,char*auth_name,VALUE_PAIR*check_first)
+int 
+user_auth_name(char*rname,char*auth_name,VALUE_PAIR*check_first)
 {
 	VALUE_PAIR	*fix;
 	int		req_len;
@@ -325,7 +327,8 @@ int user_auth_name(char*rname,char*auth_name,VALUE_PAIR*check_first)
  *
  *************************************************************************/
 
-int userparse(char*buffer,VALUE_PAIR**first_pair)
+int 
+userparse(char*buffer,VALUE_PAIR**first_pair)
 {
 	int		mode;
 	char		attrstr[64];
@@ -382,6 +385,18 @@ int userparse(char*buffer,VALUE_PAIR**first_pair)
 
 			switch(pair->type) {
 
+#if defined(ASCEND_BINARY)
+                        case PW_TYPE_ABINARY:
+                               /*
+                                * special case to convert filter to binary
+                                */
+                               if ( filterBinary( pair, valstr ) == -1 ) {
+                                       free(pair);
+                                       return(-1);
+                               }
+                               break;
+#endif
+			       
 			case PW_TYPE_STRING:
 				strcpy(pair->strvalue, valstr);
 				pair->lvalue = strlen(valstr);
@@ -466,7 +481,8 @@ static char *months[] = {
 	"Jan", "Feb", "Mar", "Apr", "May", "Jun",
 	"Jul", "Aug", "Sep", "Oct", "Nov", "Dec" };
 
-int user_gettime( char*valstr,struct tm*tm )
+int 
+user_gettime( char*valstr,struct tm*tm )
 {
 	int	i;
 
@@ -506,7 +522,8 @@ int user_gettime( char*valstr,struct tm*tm )
  *
  *************************************************************************/
 
-USER_FILE user_open(void)
+USER_FILE 
+user_open(void)
 {
 	static USER_FILE user_file;
 	char buffer[PATH_MAX];
@@ -529,7 +546,8 @@ USER_FILE user_open(void)
 	return user_file;
 }
 
-FILE * user_open_flat(char*file_name)
+FILE * 
+user_open_flat(char*file_name)
 {
 	FILE*user_desc;
 
@@ -551,7 +569,8 @@ FILE * user_open_flat(char*file_name)
  *
  *************************************************************************/
 
-void user_close(USER_FILE user_file)
+void 
+user_close(USER_FILE user_file)
 {
         if (radius_gdbm != 0) gdbm_close(user_file.gdbm);
         else fclose(user_file.flat);
