@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 1999-2002 Francesco P. Lovergine. 
+ * Copyright (C) 1999-2004 Francesco P. Lovergine. 
  * All rights reserved.
  *
  * This program is free software; you can redistribute it and/or modify
@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: util.c,v 1.5 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: util.c 81 2004-08-27 21:45:17Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -38,7 +38,8 @@ int tmemreq = 0;
  *
  *************************************************************************/
 
-char* ip_hostname(UINT4 ipaddr)
+char* 
+ip_hostname(UINT4 ipaddr)
 {
 	struct	hostent *hp;
 	static char	hstname[128];
@@ -62,7 +63,8 @@ char* ip_hostname(UINT4 ipaddr)
  *
  *************************************************************************/
 
-UINT4 get_ipaddr(char *host)
+UINT4 
+get_ipaddr(char *host)
 {
 	struct hostent *hp;
 
@@ -83,7 +85,8 @@ UINT4 get_ipaddr(char *host)
  *
  *************************************************************************/
 
-int good_ipaddr(char*addr)
+int 
+good_ipaddr(char*addr)
 {
 	int	dot_count;
 	int	digit_count;
@@ -123,7 +126,8 @@ int good_ipaddr(char*addr)
  *
  *************************************************************************/
 
-void ipaddr2str(char*buffer,size_t buflen,UINT4 ipaddr)
+void 
+ipaddr2str(char*buffer,size_t buflen,UINT4 ipaddr)
 {
 	int	addr_byte[4];
 	int	i;
@@ -147,7 +151,8 @@ void ipaddr2str(char*buffer,size_t buflen,UINT4 ipaddr)
  *
  *************************************************************************/
 
-char*ipaddr2strp(UINT4 ipaddr)
+char*
+ipaddr2strp(UINT4 ipaddr)
 {
 	int	addr_byte[4];
 	int	i;
@@ -174,7 +179,8 @@ char*ipaddr2strp(UINT4 ipaddr)
  *
  *************************************************************************/
 
-UINT4 ipstr2long(char*ip_str)
+UINT4 
+ipstr2long(char*ip_str)
 {
 	char	buf[6];
 	char	*ptr;
@@ -220,7 +226,8 @@ UINT4 ipstr2long(char*ip_str)
  *
  *************************************************************************/
 
-char* req2str(char *buffer,size_t buflen,AUTH_REQ *authreq)
+char* 
+req2str(char *buffer,size_t buflen,AUTH_REQ *authreq)
 {
 	int	addr_byte[4];
 	int	i;
@@ -250,7 +257,8 @@ char* req2str(char *buffer,size_t buflen,AUTH_REQ *authreq)
 }
 
 
-char* req2strp(AUTH_REQ *authreq)
+char* 
+req2strp(AUTH_REQ *authreq)
 {
 	static char buffer[32];
 
@@ -266,7 +274,8 @@ char* req2strp(AUTH_REQ *authreq)
  *
  *************************************************************************/
 
-char * bufalloc(int size,char*where)
+char * 
+bufalloc(int size,char*where)
 {
 	char 		*buf;
 
@@ -298,7 +307,8 @@ char * bufalloc(int size,char*where)
  *
  *************************************************************************/
 
-void buffree(char*buf,char*where)
+void 
+buffree(char*buf,char*where)
 {
 	if (debug_mem) {
 		log_err("called buffree(%x,%s) = %d\n",(int)buf,where,nmembuf);
@@ -321,7 +331,8 @@ void buffree(char*buf,char*where)
  *
  *************************************************************************/
 
-VALUE_PAIR *pairalloc(char*where)
+VALUE_PAIR *
+pairalloc(char*where)
 {
 	VALUE_PAIR	*pair;
 
@@ -353,7 +364,8 @@ VALUE_PAIR *pairalloc(char*where)
  *
  *************************************************************************/
 
-void pairfree(VALUE_PAIR*pair,char*where)
+void 
+pairfree(VALUE_PAIR*pair,char*where)
 {
 	VALUE_PAIR	*next;
 
@@ -376,7 +388,8 @@ void pairfree(VALUE_PAIR*pair,char*where)
  *
  *************************************************************************/
 
-PEER * peeralloc(char *where)
+PEER * 
+peeralloc(char *where)
 {
 	PEER		*peer;
 
@@ -408,13 +421,14 @@ PEER * peeralloc(char *where)
  *
  *************************************************************************/
 
-void peerfree(PEER*peer,char*where)
+void 
+peerfree(PEER*peer,char*where)
 {
 	if (peer == (PEER *)NULL) {
 		log_err("%s called peerfree with NULL pointer\n",where);
 	} else {
 		if (peer->next != (PEER *)NULL) {
-			__debug("%s called peerfree with live next pointer\n",
+			debug("%s called peerfree with live next pointer\n",
 				where);
 		}
 		memset(peer,0,sizeof(PEER));
@@ -434,7 +448,8 @@ void peerfree(PEER*peer,char*where)
  *
  *************************************************************************/
 
-AUTH_REQ *reqalloc(char *where)
+AUTH_REQ *
+reqalloc(char *where)
 {
 	AUTH_REQ	*authreq;
 
@@ -471,7 +486,8 @@ AUTH_REQ *reqalloc(char *where)
  *
  *************************************************************************/
 
-void reqfree( AUTH_REQ*authreq,char*where)
+void 
+reqfree( AUTH_REQ*authreq,char*where)
 {
 	if (debug_mem) {
 		log_err("called reqfree(%x,%s) = %d\n",(int)authreq,where,nmemreq);
@@ -489,7 +505,8 @@ void reqfree( AUTH_REQ*authreq,char*where)
 	}
 }
 
-void memreport(void)
+void 
+memreport(void)
 {
 	log_err("memory usage = pair %d/%d/%d  peer %d/%d/%d  req %d/%d/%d  buf %d/%d/%d\n",
 	nmempair,hmempair,tmempair, nmempeer,hmempeer,tmempeer, 
@@ -507,7 +524,8 @@ void memreport(void)
  *
  *************************************************************************/
 
-void fprint_attr_val(FILE*fd,VALUE_PAIR*pair)
+void 
+fprint_attr_val(FILE*fd,VALUE_PAIR*pair)
 {
 	DICT_VALUE	*dval;
 	char		buffer[32];
@@ -556,6 +574,23 @@ void fprint_attr_val(FILE*fd,VALUE_PAIR*pair)
 		snprintf(prtbuf,sizeof(prtbuf),"%s = \"%s\"", pair->name, buffer);
 		break;
 
+#if defined(ASCEND_BINARY)
+       case PW_TYPE_ABINARY:
+               {
+                       int i;
+               
+                       snprintf( prtbuf, sizeof(prtbuf),"%s =", pair->name );
+		       ptr = (u_char *)pair->strvalue;
+		       len = pair->lvalue;
+                       for ( i=0; i<len; i++ ) {
+                                snprintf( buffer, sizeof(buffer)," %02x", ptr[i] );
+				strncat( prtbuf,buffer,sizeof(prtbuf)-strlen(prtbuf)-1 );
+                       }
+               }
+               break;
+#endif
+
+
 	default:
 		snprintf(prtbuf,sizeof(prtbuf),"Unknown type %d", pair->type);
 		break;
@@ -570,7 +605,8 @@ void fprint_attr_val(FILE*fd,VALUE_PAIR*pair)
 	}
 }
 
-void fprint_attr_putc(u_char cc,u_char *buf)
+void 
+fprint_attr_putc(u_char cc,u_char *buf)
 {
 	int len;
 
@@ -588,7 +624,8 @@ void fprint_attr_putc(u_char cc,u_char *buf)
  *
  *************************************************************************/
 
-void hexdump(u_char*buf,int n)
+void 
+hexdump(u_char*buf,int n)
 {
 	int i;
 	int j;
