@@ -7,7 +7,7 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: version.c,v 1.3 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: version.c 75 2004-08-02 18:40:07Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
@@ -16,7 +16,7 @@ static char rcsid[] = "$Id: version.c,v 1.3 2002/03/05 19:17:57 kiavik Exp $";
 /*  If you make any changes to this software please update this version number
  */
 
-#define	 STRVER "%s : YARD Radius Server %s $Date: 2002/03/05 19:17:57 $ "
+#define	 STRVER "%s : YARD Radius Server %s $Date: 2004-08-02 20:40:07 +0200 (lun, 02 ago 2004) $ "
 
 /*************************************************************************
  *
@@ -26,51 +26,55 @@ static char rcsid[] = "$Id: version.c,v 1.3 2002/03/05 19:17:57 kiavik Exp $";
  *
  *************************************************************************/
 
-void version(void)
+void 
+version(void)
 {
-	char	buffer[1024];
+	char buffer[1024];
 
-	build_version(buffer);
+	build_version(buffer,sizeof(buffer));
 	fprintf(stderr, buffer);
 	exit(-1);
 }
 
-void log_version()
+void 
+log_version(void)
 {
 	char buffer[1024];
 
-	build_version(buffer);
+	build_version(buffer,sizeof(buffer));
 	log_info("%s",buffer);
 }
 
-void build_version(char *bp)
+void 
+build_version(char *bp,size_t sizeofbp)
 {
-	sprintf(bp, STRVER, progname, VERSION);
+	snprintf(bp,sizeofbp-1,STRVER, progname, VERSION);
 
 	/* here are all the conditional feature flags */
 
 # if defined(ACTIVCARD)
-	strcat(bp," ACTIVCARD");
+	strncat(bp," ACTIVCARD",sizeofbp-strlen(bp)-1);
 # endif
 
 # if defined(IPASS)
-	strcat(bp," IPASS");
+	strncat(bp," IPASS",sizeofbp-strlen(bp)-1);
 # endif
 
 # if defined(SECURID)
-	strcat(bp," SECURID");
+	strncat(bp," SECURID",sizeofbp-strlen(bp)-1);
 # endif
 
 #if defined(SHADOW_PASSWORD)
-	strcat(bp," SHADOW");	/* system has no /usr/include/shadow.h */
+	strncat(bp," SHADOW",sizeofbp-strlen(bp)-1);	/* system has no /usr/include/shadow.h */
 #endif
 
 	/* here are all the system definitions compilation uses */
 
-	strcat(bp," "); strcat(bp,HOSTINFO);
+	strncat(bp," ",sizeofbp-strlen(bp)-1); 
+	strncat(bp,HOSTINFO,sizeofbp-strlen(bp)-1);
 	if (accept_zero) {
-		strcat(bp, " zero_accepted");
+		strncat(bp," zero_accepted",sizeofbp-strlen(bp)-1);
 	}
-	strcat(bp, radius_gdbm ? " gdbm_users" : " flat_users");
-	strcat(bp,"\n");
+	strncat(bp, radius_gdbm ? " gdbm_users" : " flat_users",sizeofbp-strlen(bp)-1);
+	strncat(bp,"\n",sizeofbp-strlen(bp)-1);
 }
