@@ -7,14 +7,15 @@
  * enclosed with sources.
  */
 
-static char rcsid[] = "$Id: vports.c,v 1.4 2002/03/05 19:17:57 kiavik Exp $";
+static char rcsid[] = "$Id: vports.c 81 2004-08-27 21:45:17Z flovergine $";
 
 #include "yard.h"
 #include "global.h"
 
 #ifdef VPORTS
 
-int vports_init(void)
+int 
+vports_init(void)
 {
 	FILE	*f1;
 	char	s[PATH_MAX], s2[16];
@@ -24,7 +25,7 @@ int vports_init(void)
 	snprintf(s,sizeof(s),"%s/%s", radius_dir, RADIUS_VPORTS);
 	f1 = fopen(s, "rt");
 	if (f1 != NULL) {
-		__debug("Found VPORTS, reading in list\n");
+		debug("Found VPORTS, reading in list\n");
 		while(fgets(s, 256, f1) != NULL) {
 			s[strlen(s)-1] = '\0';	/* Strip off CR */
 			sscanf(s, "%s %s", cid, s2);
@@ -37,7 +38,8 @@ int vports_init(void)
 	return 0;
 }
 
-VP_CALLED * begin_cidlist(void)
+VP_CALLED * 
+begin_cidlist(void)
 {
 	if ((cidfirst = malloc(sizeof(VP_CALLED))) == NULL) {
 		log_err("begin_cidlist: Could not allocate memory!\n");
@@ -50,7 +52,8 @@ VP_CALLED * begin_cidlist(void)
 	return (VP_CALLED *)cidfirst;
 }
 
-VP_CALLED *new_cidlist(void)
+VP_CALLED *
+new_cidlist(void)
 {
 	VP_CALLED *cidcur;
 
@@ -75,7 +78,8 @@ VP_CALLED *new_cidlist(void)
 	return (VP_CALLED *)cidcur;
 }
 
-VP_CALLED *get_cidlist(u_char *num)
+VP_CALLED *
+get_cidlist(u_char *num)
 {
 	VP_CALLED *cidcur;
 
@@ -89,7 +93,8 @@ VP_CALLED *get_cidlist(u_char *num)
 	return (VP_CALLED *)NULL;
 }
 
-void create_cidlist(u_char*num,int max)
+void 
+create_cidlist(u_char*num,int max)
 {
 	VP_CALLED *cidcur;
 
@@ -104,7 +109,8 @@ void create_cidlist(u_char*num,int max)
 	return;
 }
 
-int vports_in_use(VP_CALLED *cidcur)
+int 
+vports_in_use(VP_CALLED *cidcur)
 {
 	VP_NAS	*nasip_cur;
 	VP_ACCTID	*acctid_cur;
@@ -127,7 +133,8 @@ int vports_in_use(VP_CALLED *cidcur)
 	return ret;
 }
 
-int vports_in_cache(VP_CALLED *cidcur)
+int 
+vports_in_cache(VP_CALLED *cidcur)
 {
 	VP_CALLCACHE	*cc_cur;
 	u_int		ret;
@@ -154,7 +161,8 @@ int vports_in_cache(VP_CALLED *cidcur)
 	return ret;
 }
 		
-VP_NAS *begin_nasiplist(VP_CALLED *cidcur)
+VP_NAS *
+begin_nasiplist(VP_CALLED *cidcur)
 {
 	if ((cidcur->nasip_first = malloc(sizeof(VP_NAS))) == NULL) {
 		log_err("begin_nasiplist: Could not allocate memory!\n");
@@ -169,7 +177,8 @@ VP_NAS *begin_nasiplist(VP_CALLED *cidcur)
 	return (VP_NAS *)cidcur->nasip_first;
 }
 
-void free_single_nasiplist(VP_CALLED *cidcur,VP_NAS *nasip_cur)
+void 
+free_single_nasiplist(VP_CALLED *cidcur,VP_NAS *nasip_cur)
 {
 	VP_NAS		*next, *prev;
 	VP_ACCTID	*acctid_cur;
@@ -202,7 +211,8 @@ void free_single_nasiplist(VP_CALLED *cidcur,VP_NAS *nasip_cur)
 	return;
 }
 
-VP_NAS *get_nasiplist(VP_CALLED *cidcur,UINT4 addr)
+VP_NAS *
+get_nasiplist(VP_CALLED *cidcur,UINT4 addr)
 {
 	VP_NAS	*nasip_cur;
 
@@ -216,7 +226,8 @@ VP_NAS *get_nasiplist(VP_CALLED *cidcur,UINT4 addr)
 	return nasip_cur;
 }
 
-VP_NAS *new_nasiplist(VP_CALLED *cidcur,UINT4 addr)
+VP_NAS *
+new_nasiplist(VP_CALLED *cidcur,UINT4 addr)
 {
 	VP_NAS	*nasip_cur;
 
@@ -243,7 +254,8 @@ VP_NAS *new_nasiplist(VP_CALLED *cidcur,UINT4 addr)
 	return (VP_NAS *)nasip_cur;
 }
 
-VP_CALLCACHE* begin_cclist(VP_CALLED *cidcur)
+VP_CALLCACHE* 
+begin_cclist(VP_CALLED *cidcur)
 {
 	if ((cidcur->cc_first = malloc(sizeof(VP_CALLCACHE))) == NULL) {
 		log_err("begin_cclist: Could not allocate memory!\n");
@@ -257,7 +269,8 @@ VP_CALLCACHE* begin_cclist(VP_CALLED *cidcur)
 	return (VP_CALLCACHE *)cidcur->cc_first;
 }
 
-void free_single_cclist(VP_CALLED *cidcur,VP_CALLCACHE *cc_cur)
+void 
+free_single_cclist(VP_CALLED *cidcur,VP_CALLCACHE *cc_cur)
 {
 	VP_CALLCACHE	*next, *prev;
 
@@ -277,7 +290,8 @@ void free_single_cclist(VP_CALLED *cidcur,VP_CALLCACHE *cc_cur)
 	return;
 }
 
-VP_CALLCACHE *new_cclist(VP_CALLED *cidcur)
+VP_CALLCACHE *
+new_cclist(VP_CALLED *cidcur)
 {
 	VP_CALLCACHE	*cc_cur;
 
@@ -299,7 +313,8 @@ VP_CALLCACHE *new_cclist(VP_CALLED *cidcur)
 	return (VP_CALLCACHE *)cc_cur;
 }
 
-VP_ACCTID *begin_acctidlist(VP_NAS *nasip_cur)
+VP_ACCTID *
+begin_acctidlist(VP_NAS *nasip_cur)
 {
 	if ((nasip_cur->acctid_first = malloc(sizeof(VP_ACCTID))) == NULL) {
 		log_err("begin_acctidlist: Could not allocate memory!\n");
@@ -313,7 +328,8 @@ VP_ACCTID *begin_acctidlist(VP_NAS *nasip_cur)
 	return (VP_ACCTID *)nasip_cur->acctid_first;
 }
 
-void free_single_acctidlist( VP_NAS *nasip_cur,VP_ACCTID *acctid_cur )
+void 
+free_single_acctidlist( VP_NAS *nasip_cur,VP_ACCTID *acctid_cur )
 {
 	VP_ACCTID	*next, *prev;
 
@@ -333,7 +349,8 @@ void free_single_acctidlist( VP_NAS *nasip_cur,VP_ACCTID *acctid_cur )
 	return;
 }
 
-VP_ACCTID * get_acctidlist( VP_NAS *nasip_cur,u_char *acctid )
+VP_ACCTID * 
+get_acctidlist( VP_NAS *nasip_cur,u_char *acctid )
 {
 	VP_ACCTID	*acctid_cur;
 
@@ -348,7 +365,8 @@ VP_ACCTID * get_acctidlist( VP_NAS *nasip_cur,u_char *acctid )
 	return (VP_ACCTID *)NULL;
 }
 
-VP_ACCTID * new_acctidlist(VP_NAS *nasip_cur,u_char *acctid)
+VP_ACCTID * 
+new_acctidlist(VP_NAS *nasip_cur,u_char *acctid)
 {
 	VP_ACCTID	*acctid_cur;
 
@@ -374,7 +392,8 @@ VP_ACCTID * new_acctidlist(VP_NAS *nasip_cur,u_char *acctid)
 	return (VP_ACCTID *)acctid_cur;
 }
 
-int vp_check_req(AUTH_REQ *authreq)
+int 
+vp_check_req(AUTH_REQ *authreq)
 {
 	VALUE_PAIR		*vp;
 	VP_CALLED		*cidcur;
@@ -417,7 +436,7 @@ int vp_check_req(AUTH_REQ *authreq)
 	in_use = vports_in_use(cidcur) + vports_in_cache(cidcur);
 	if (in_use >= cidcur->max)
 	{
-		__debug("VPORTS: Rejecting Request, no ports available in pool %s [%d inuse, %d cached, %d max]\n",
+		debug("VPORTS: Rejecting Request, no ports available in pool %s [%d inuse, %d cached, %d max]\n",
 				cidcur->num, vports_in_use(cidcur),
 				vports_in_cache(cidcur), cidcur->max);
 		return VP_RET_REJECT;
@@ -425,14 +444,15 @@ int vp_check_req(AUTH_REQ *authreq)
 	else
 	{
 		new_cclist(cidcur);
-		__debug("VPORTS: Accepting Request to Virtual Pool %s [%d inuse, %d cached, %d max]\n",
+		debug("VPORTS: Accepting Request to Virtual Pool %s [%d inuse, %d cached, %d max]\n",
 				cidcur->num, vports_in_use(cidcur),
 				vports_in_cache(cidcur), cidcur->max);
 		return VP_RET_ACCEPT;
 	}
 }
 
-void vp_update_cid(AUTH_REQ*authreq)
+void 
+vp_update_cid(AUTH_REQ*authreq)
 {
 	VALUE_PAIR		*vp;
 	VP_CALLED		*cidcur;
@@ -483,7 +503,7 @@ void vp_update_cid(AUTH_REQ*authreq)
 	if (required != 4)
 		return;
 	if (reboot_req == 0) {
-		__debug("vports: NAS %s rebooted - clearing ports\n",
+		debug("vports: NAS %s rebooted - clearing ports\n",
 			ipaddr2strp(addr));
 		cidcur = cidfirst;
 		while(cidcur != NULL) {
@@ -507,7 +527,7 @@ void vp_update_cid(AUTH_REQ*authreq)
 		}
 		nasip_cur = new_nasiplist(cidcur, addr);
 		acctid_cur = new_acctidlist(nasip_cur, acct_id);
-		__debug("VPORTS: Added Session ID %s to the %s pool [%d inuse, %d cached, %d max]\n",
+		debug("VPORTS: Added Session ID %s to the %s pool [%d inuse, %d cached, %d max]\n",
 		acct_id, called_sid, vports_in_use(cidcur),
 		vports_in_cache(cidcur), cidcur->max);
 		break;
@@ -519,7 +539,7 @@ void vp_update_cid(AUTH_REQ*authreq)
 			if (acctid_cur != NULL)
 			{
 				free_single_acctidlist(nasip_cur, acctid_cur);
-				__debug("VPORTS: Removed Session ID %s from the %s pool [%d inuse, %d cached, %d max]\n",
+				debug("VPORTS: Removed Session ID %s from the %s pool [%d inuse, %d cached, %d max]\n",
 				acct_id, called_sid, vports_in_use(cidcur),
 				vports_in_cache(cidcur), cidcur->max);
 			}
